<?php
/**
 * Plugin Name: Apus Apuslisting
 * Plugin URI: http://apusthemes.com/booking/
 * Description: Apus Apuslisting is a plugin for Apuslisting directory listing theme
 * Version: 1.0.0
 * Author: ApusTheme
 * Author URI: http://apusthemes.com
 * Requires at least: 3.8
 * Tested up to: 4.1
 *
 * Text Domain: apus-apuslisting
 * Domain Path: /languages/
 *
 * @package apus-apuslisting
 * @category Plugins
 * @author ApusTheme
 */
if ( ! defined( 'ABSPATH' ) ) exit;

if( !class_exists("ApusApusListing") ){
	
	final class ApusApusListing{

		private static $instance;

		public static function getInstance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof ApusApusListing ) ) {
				self::$instance = new ApusApusListing;
				self::$instance->setup_constants();

				add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );

				self::$instance->includes();
			}

			return self::$instance;
		}

		/**
		 *
		 */
		public function setup_constants(){
			// Plugin version
			if ( ! defined( 'APUSAPUSLISTING_VERSION' ) ) {
				define( 'APUSAPUSLISTING_VERSION', '1.0.0' );
			}

			// Plugin Folder Path
			if ( ! defined( 'APUSAPUSLISTING_PLUGIN_DIR' ) ) {
				define( 'APUSAPUSLISTING_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}

			// Plugin Folder URL
			if ( ! defined( 'APUSAPUSLISTING_PLUGIN_URL' ) ) {
				define( 'APUSAPUSLISTING_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
			}

			// Plugin Root File
			if ( ! defined( 'APUSAPUSLISTING_PLUGIN_FILE' ) ) {
				define( 'APUSAPUSLISTING_PLUGIN_FILE', __FILE__ );
			}

			// Prefix
			if ( ! defined( 'APUSAPUSLISTING_PREFIX' ) ) {
				define( 'APUSAPUSLISTING_PREFIX', 'apus_apuslisting_' );
			}
		}

		public function includes() {
			// cmb2 custom field
			if ( ! class_exists( 'Taxonomy_MetaData_CMB2' ) ) {
				require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/vendors/cmb2/taxonomy/Taxonomy_MetaData_CMB2.php';
			}
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/mixes-functions.php';
			
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/class-template-loader.php';
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/class-favorite.php';
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/class-attachments.php';
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/class-claim.php';
			require_once APUSAPUSLISTING_PLUGIN_DIR . 'inc/class-products.php';
			

			apusapuslisting_includes( APUSAPUSLISTING_PLUGIN_DIR . 'inc/taxonomies/*.php' );
			apusapuslisting_includes( APUSAPUSLISTING_PLUGIN_DIR . 'inc/post-types/*.php' );

			add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'scripts' ) );
		}
		public function scripts() {
			wp_register_script( 'apusapuslisting-scripts', APUSAPUSLISTING_PLUGIN_URL . 'assets/scripts.js', array( 'jquery' ), '', true );

			wp_localize_script( 'apusapuslisting-scripts', 'apusapuslisting_vars', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
			));
			wp_enqueue_script( 'apusapuslisting-scripts' );
		}
		/**
		 *
		 */
		public function load_textdomain() {
			// Set filter for ApusApusListing's languages directory
			$lang_dir = dirname( plugin_basename( APUSAPUSLISTING_PLUGIN_FILE ) ) . '/languages/';
			$lang_dir = apply_filters( 'apusapuslisting_languages_directory', $lang_dir );

			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', get_locale(), 'apus-apuslisting' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'apus-apuslisting', $locale );

			// Setup paths to current locale file
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = WP_LANG_DIR . '/apus-apuslisting/' . $mofile;

			if ( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/apus-apuslisting folder
				load_textdomain( 'apus-apuslisting', $mofile_global );
			} elseif ( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/apus-apuslisting/languages/ folder
				load_textdomain( 'apus-apuslisting', $mofile_local );
			} else {
				// Load the default language files
				load_plugin_textdomain( 'apus-apuslisting', false, $lang_dir );
			}
		}
	}
}

function ApusApusListing() {
	return ApusApusListing::getInstance();
}

ApusApusListing();
