<?php
/**
 * apus apuslisting
 *
 * @package    apus-apuslisting
 * @author     ApusTheme <apusthemes@gmail.com >
 * @license    GNU General Public License, version 3
 * @copyright  13/06/2016 ApusTheme
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class ApusApusListing_Post_Type_Job_Listing{

	public static function init() {
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'admin_enqueue_scripts' ) );
		// save [front, back]
		add_filter( 'register_post_type_job_listing', array( __CLASS__, 'change_post_type_label' ), 10 );
		add_filter( 'manage_edit-job_listing_columns', array( __CLASS__, 'job_listing_admin_columns' ), 100 );
		// custom fields
		add_filter( 'cmb2_meta_boxes', array( __CLASS__, 'metaboxes' ) );
		add_filter( 'job_manager_job_listing_data_fields', array( __CLASS__, 'add_custom_fields' ), 1 );
		add_filter( 'submit_job_form_fields', array( __CLASS__, 'custom_submit_job_form_fields' ) );
		add_action( 'job_manager_input_apuslisting_hours', array( __CLASS__, 'input_hours_fields' ), 10, 2 );

		add_action( 'job_manager_input_apuslisting_location', array( __CLASS__, 'input_location_fields' ), 10, 2 );

		add_action( 'add_meta_boxes', array( __CLASS__, 'add_meta_boxes' ) );
		
		// get current value
		add_filter( 'submit_job_form_fields_get_job_data', array( __CLASS__, 'get_job_data' ), 10, 2 );
		// front-end
		add_filter( 'submit_job_form_save_job_data', array( __CLASS__, 'clean_gallery_images_on_submit' ), 10, 5);
		add_action( 'job_manager_update_job_data', array( __CLASS__, 'listing_submit' ), 10, 2 );
		add_action( 'job_manager_save_job_listing', array( __CLASS__, 'listing_update_job_data' ), 10, 2 );
	}

	public static function change_post_type_label($args) {
		$singular = esc_html__( 'Listing', 'apus-apuslisting' );
		$plural   = esc_html__( 'Listings', 'apus-apuslisting' );

		$args['labels']      = array(
			'name'               => $plural,
			'singular_name'      => $singular,
			'menu_name'          => $plural,
			'all_items'          => sprintf( esc_html__( 'All %s', 'apus-apuslisting' ), $plural ),
			'add_new'            => esc_html__( 'Add New', 'apus-apuslisting' ),
			'add_new_item'       => sprintf( esc_html__( 'Add %s', 'apus-apuslisting' ), $singular ),
			'edit'               => esc_html__( 'Edit', 'apus-apuslisting' ),
			'edit_item'          => sprintf( esc_html__( 'Edit %s', 'apus-apuslisting' ), $singular ),
			'new_item'           => sprintf( esc_html__( 'New %s', 'apus-apuslisting' ), $singular ),
			'view'               => sprintf( esc_html__( 'View %s', 'apus-apuslisting' ), $singular ),
			'view_item'          => sprintf( esc_html__( 'View %s', 'apus-apuslisting' ), $singular ),
			'search_items'       => sprintf( esc_html__( 'Search %s', 'apus-apuslisting' ), $plural ),
			'not_found'          => sprintf( esc_html__( 'No %s found', 'apus-apuslisting' ), $plural ),
			'not_found_in_trash' => sprintf( esc_html__( 'No %s found in trash', 'apus-apuslisting' ), $plural ),
			'parent'             => sprintf( esc_html__( 'Parent %s', 'apus-apuslisting' ), $singular )
		);
		$args['description'] = sprintf( esc_html__( 'This is where you can create and manage %s.', 'apus-apuslisting' ), $plural );
		$args['supports']    = array( 'title', 'editor', 'custom-fields', 'publicize', 'comments', 'thumbnail' );
		$args['rewrite']     = array( 'slug' => 'listings' );		
		$args['has_archive'] = 'listings';
		
		return $args;
	}

	public static function admin_enqueue_scripts() {
		global $pagenow;

		if ( ! ( in_array( $pagenow, array( 'post-new.php', 'post.php'  )) && get_post_type() == 'job_listing' ) ) {
			return;
		}

		wp_enqueue_script( 'timepicker', get_template_directory_uri() . '/assets/js/timepicker/jquery.timepicker.min.js' );
		wp_enqueue_style( 'timepicker', get_template_directory_uri() . '/assets/js/timepicker/jquery.timepicker.css' );
	}

	public static function metaboxes( array $metaboxes ) {
		$prefix = APUSAPUSLISTING_PREFIX;
		
		$metaboxes[ $prefix . 'info' ] = array(
			'id'                        => $prefix . 'info',
			'title'                     => __( 'Gallery Images', 'apus-apuslisting' ),
			'object_types'              => array( 'job_listing' ),
			'context'                   => 'side',
			'priority'                  => 'low',
			'show_names'                => true,
			'fields'                    => apply_filters( 'apus_apuslisting_postype_apb_room_type_metaboxes_fields_management', array(
				   	array(
					    'name' => '',
					    'id'   => $prefix . 'gallery_images',
					    'type' => 'file_list',
					    'text' => array(
					        'add_upload_files_text' => esc_html__('Add Images', 'apus-apuslisting'),
					        'remove_image_text' => esc_html__('Remove Image', 'apus-apuslisting'),
					        'file_text' => esc_html__('File:', 'apus-apuslisting'),
					        'file_download_text' => esc_html__('Download', 'apus-apuslisting'),
					        'remove_text' => esc_html__('Remove', 'apus-apuslisting'),
					    ),
					)
				)
			)
		);
		return $metaboxes;
	}
	
	public static function price_ranges() {
		return apply_filters( 'apus_apuslisting_price_ranges', array(
				'inexpensive' => esc_html__('$ - Inexpensive', 'apus-apuslisting'),
				'moderate' => esc_html__('$$ - Moderate', 'apus-apuslisting'),
				'pricey' => esc_html__('$$$ - Pricey', 'apus-apuslisting'),
				'ultra_high_end' => esc_html__('$$$$ - Ultra High', 'apus-apuslisting'),
			));
	}

	public static function add_custom_fields( $fields ) {

		// reorder fields
		$fields['_job_location']['priority']    = 2.2;
		$fields['_company_website']['priority'] = 2.5;
		$fields['_company_twitter']['priority'] = 2.6;

		$fields['_claimed'] = array(
			'label'       => esc_html__( 'Claimed:', 'wp-job-manager' ),
			'type'        => 'checkbox',
			'description' => esc_html__( 'The owner has been verified.', 'apus-apuslisting' ),
			'priority'    => 2.3
		);
		$fields['_company_phone'] = array(
			'label'       => esc_html__( 'Phone', 'apus-apuslisting' ),
	//		'type'        => 'number',
			'placeholder' => esc_html__( 'e.g +84-669-996', 'apus-apuslisting' ),
	//		'description' => ''
			'priority'    => 2.4
		);

		$fields['_company_email'] = array(
			'label'       => esc_html__( 'Email', 'apus-apuslisting' ),
	//		'type'        => 'number',
			'placeholder' => esc_html__( 'youremail@email.com', 'apus-apuslisting' ),
	//		'description' => ''
			'priority'    => 2.5
		);

		$fields['_company_twitter']['label'] = esc_html__('Twitter url', 'apus-apuslisting');
		$fields['_company_twitter']['placeholder'] = 'http://twitter.com/yourusername';
		$fields['_company_facebook'] = array(
			'label' => esc_html__('Facebook url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://facebook.com/yourusername',
			'priority' => 2.7
		);
		$fields['_company_linkedin'] = array(
			'label' => esc_html__('Linkedin url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://linkedin.com/yourusername',
			'priority' => 2.8
		);
		$fields['_company_pinterest'] = array(
			'label' => esc_html__('Pinterest url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://pinterest.com/yourusername',
			'priority' => 2.9
		);
		$fields['_company_instagram'] = array(
			'label' => esc_html__('Instagram url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://instagram.com/yourusername',
			'priority' => 3.0
		);

		$fields['_company_price_range'] = array(
			'label' => esc_html__('Price Range', 'apus-apuslisting'),
			'type' => 'select',
			'required' => false,
			'placeholder' => '',
			'priority' => 4.1,
			'options' => self::price_ranges()
		);
		$fields['_company_price_from'] = array(
			'label' => esc_html__('Price From', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => '',
			'priority' => 4.1
		);
		$fields['_company_price_to'] = array(
			'label' => esc_html__('Price To', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => '',
			'priority' => 4.2
		);

		unset( $fields['_company_tagline'] );
		unset( $fields['_company_logo'] );
		unset( $fields['_company_name'] );
		unset( $fields['_application'] );
		return $fields;
	}

	public static function custom_submit_job_form_fields( $fields ) {
		array_walk_recursive( $fields, array( __CLASS__, 'replace_jobs_with_listings' ) );

		$fields['company']['company_twitter']['label'] = esc_html__('Twitter url', 'apus-apuslisting');
		$fields['company']['company_twitter']['placeholder'] = 'http://twitter.com/yourusername';
		$fields['company']['company_facebook'] = array(
			'label' => esc_html__('Facebook url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://facebook.com/yourusername',
			'priority' => 6
		);
		$fields['company']['company_linkedin'] = array(
			'label' => esc_html__('Linkedin url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://linkedin.com/yourusername',
			'priority' => 6.1
		);
		$fields['company']['company_pinterest'] = array(
			'label' => esc_html__('Pinterest url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://pinterest.com/yourusername',
			'priority' => 6.2
		);
		$fields['company']['company_instagram'] = array(
			'label' => esc_html__('Instagram url', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'placeholder' => 'http://instagram.com/yourusername',
			'priority' => 6.3
		);

		// uncomment here to see what you can do

		$fields['job']['job_title']['label']       = esc_html__( 'Listing Name', 'apus-apuslisting' );
		$fields['job']['job_title']['placeholder'] = esc_html__( 'Your listing name', 'apus-apuslisting' );

		$fields['job']['job_description']['priority']    = 2.2;
	//	$fields['job']['job_description']['type']        = 'textarea';
		$fields['job']['job_description']['placeholder'] = esc_html__( 'An overview of your listing and the things you love about it.', 'apus-apuslisting' );

		// location
		$fields['job']['job_location']['type']    = 'apuslisting-location';
		$fields['job']['job_location']['priority']    = 2.3;
		$fields['job']['job_location']['placeholder'] = esc_html__( 'e.g 34 Wigmore Street, London', 'apus-apuslisting' );
		$fields['job']['job_location']['description'] = esc_html__( 'Leave this blank if the location is not important.', 'apus-apuslisting' );

		// category 
		$fields['job']['job_category']['priority']    = 2.4;
		$fields['job']['job_category']['placeholder'] = esc_html__( 'Choose one or more categories', 'apus-apuslisting' );

		$fields['job']['job_category']['label'] = esc_html__( 'Listing category', 'apus-apuslisting' );
		$fields['job']['job_category']['description'] = sprintf( '<span class="description_tooltip right">%s</span>', esc_html__( 'Visitors can filter their search by the categories and amenities they want - so make sure you choose them wisely and include all the relevant ones', 'apus-apuslisting' ) );

		// region
		$fields['job']['job_regions']['type']    = 'term-select';
		$fields['job']['job_regions']['taxonomy']    = 'job_listing_region';
		$fields['job']['job_regions']['priority']    = 2.5;
		$fields['job']['job_regions']['required']    = false;
		$fields['job']['job_regions']['placeholder'] = esc_html__( 'Add Region', 'apus-apuslisting' );
		$fields['job']['job_regions']['label']       = esc_html__( 'Listing Region', 'apus-apuslisting' );
		$fields['job']['job_regions']['description'] = '';
		$fields['job']['job_regions']['default'] = '';

		// amenities
		$fields['job']['job_amenities']['type']    = 'term-multiselect';
		$fields['job']['job_amenities']['taxonomy']    = 'job_listing_amenity';
		$fields['job']['job_amenities']['default']    = '';
		$fields['job']['job_amenities']['priority']    = 2.6;
		$fields['job']['job_amenities']['required']    = false;
		$fields['job']['job_amenities']['placeholder'] = esc_html__( 'Choose one or more amenities', 'apus-apuslisting' );
		$fields['job']['job_amenities']['label']       = esc_html__( 'Listing Amenities', 'apus-apuslisting' );
		$fields['job']['job_amenities']['description'] = esc_html__( 'Visitors can filter their search by the amenities too, so make sure you include all the relevant ones.', 'apus-apuslisting' );
		

		$fields['company']['company_logo']['label']       = esc_html__( 'Featured Image', 'apus-apuslisting' );
		$fields['company']['company_logo']['priority']    = 2.7;
		$fields['company']['company_logo']['multiple']    = false;
		$fields['company']['company_logo']['description'] = esc_html__( 'The image will be shown on listing cards.', 'apus-apuslisting' );

		$fields['company']['gallery_images']['label']              = esc_html__( 'Gallery Images', 'apus-apuslisting' );
		$fields['company']['gallery_images']['priority']           = 2.9;
		$fields['company']['gallery_images']['required']           = false;
		$fields['company']['gallery_images']['type']               = 'file';
		$fields['company']['gallery_images']['ajax']               = true;
		$fields['company']['gallery_images']['placeholder']        = '';
		$fields['company']['gallery_images']['allowed_mime_types'] = $fields['company']['company_logo']['allowed_mime_types'];
		$fields['company']['gallery_images']['multiple']           = true;

		
		$fields['company']['company_video']['priority']    = 3.0;

		$fields['job']['job_hours'] = array(
			'label'       => __( 'Hours of Operation', 'apus-apuslisting' ),
			'type'        => 'apuslisting-hours',
			'required'    => false,
			'placeholder' => '',
			'priority'    => 3.1,
			'default'     => ''
		);

		$fields['company']['company_phone'] = array(
			'label'       => esc_html__( 'Phone', 'apus-apuslisting' ),
			'type'        => 'text',
			'placeholder' => esc_html__( 'e.g +84-669-996', 'apus-apuslisting' ),
			'required'    => false,
			'priority'    => 3.7
		);
		$fields['company']['company_email'] = array(
			'label'       => esc_html__( 'Email', 'apus-apuslisting' ),
			'type'        => 'text',
			'placeholder' => esc_html__( 'e.g youremail@email.com', 'apus-apuslisting' ),
			'required'    => false,
			'priority'    => 3.8
		);

		$fields['company']['company_website']['priority']    = 3.2;
		$fields['company']['company_website']['placeholder'] = esc_html__( 'e.g yourwebsite.com, London', 'apus-apuslisting' );
		$fields['company']['company_website']['description'] = sprintf( '<span class="description_tooltip left">%s</span>', esc_html__( 'You can add more similar panels to better help the user fill the form', 'apus-apuslisting' ) );


		$fields['company']['company_price_range'] = array(
			'label' => esc_html__('Price Range', 'apus-apuslisting'),
			'type' => 'select',
			'required' => false,
			'priority' => 3.4,
			'options' => self::price_ranges()
		);
		$fields['company']['company_price_from'] = array(
			'label' => esc_html__('Price From', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'priority' => 3.5,
			'placeholder' => esc_html__( 'e.g $100', 'apus-apuslisting' ),
		);
		$fields['company']['company_price_to'] = array(
			'label' => esc_html__('Price To', 'apus-apuslisting'),
			'type' => 'text',
			'required' => false,
			'priority' => 3.6,
			'placeholder' => esc_html__( 'e.g $200', 'apus-apuslisting' ),
		);

		// temporary unsets
		unset( $fields['company']['company_tagline'] );
		unset( $fields['job']['job_type'] );
		unset( $fields['company']['company_name'] );
		unset( $fields['job']['application'] );
		
		
		return $fields;
	}

	public static function replace_jobs_with_listings( &$item, $key ) {

		if ( $item === 'Job Listings' ) {
			$item = esc_html__( 'Listing', 'apus-apuslisting' );
		}

		if ( $item === 'Job Submission' ) {
			$item = esc_html__( 'Submission', 'apus-apuslisting' );
		}

		if ( $key === 'desc' || $key === 'any' || $key === 'all' || $key === 'label' ) {
			if ( is_numeric( strpos( $item, 'Job' ) ) ) {
				$item = str_replace( 'Job', esc_html__( 'Listing', 'apus-apuslisting' ), $item );
			}
		}

		return $item;
	}

	public static function clean_gallery_images_on_submit( $job_data, $post_title, $post_content, $status, $values ) {
		if ( empty( $values['gallery_images'] ) ) {
			$listing = get_page_by_title( $post_title, null, 'job_listing' );
			if ( ! is_wp_error( $listing ) && isset( $listing->ID ) ) {
				$meta_key = APUSAPUSLISTING_PREFIX.'gallery_images';
				update_post_meta( $listing->ID, $meta_key, '' );
			}
		}
		return $job_data;
	}
	

	public static function listing_submit( $id, $values ) {

		$company_logo = $values['company']['gallery_images'];

		// turn company logo in featured image
		if ( isset( $company_logo ) && ! empty( $company_logo ) ) {

			$gallery_images = array();

			// we may have a simple string(on image upload) or an array of images, so we need to treat them all
			if ( is_numeric( $company_logo ) ) {
				$attach_id = self::get_attachment_id_from_url( $company_logo );
				if ( ! empty( $attach_id ) && is_numeric( $attach_id ) ) {
					$gallery_images[$attach_id] = $company_logo;
				}
			} elseif ( is_array( $company_logo ) && ! empty( $company_logo ) ) {

				foreach ( $company_logo as $key => $url ) {
					$attach_id = self::get_attachment_id_from_url( $url );
					if ( ! empty( $attach_id ) && is_numeric( $attach_id ) ) {
						$gallery_images[$attach_id] = $url;
					}
				}
			}

			// empty or not .. we're gonna update something
			$meta_key = APUSAPUSLISTING_PREFIX.'gallery_images';
			update_post_meta( $id, $meta_key, $gallery_images );
		}
		self::listing_update_job_data($id, $values);
	}

	public static function listing_update_job_data( $id, $values ) {
		if ( isset( $_POST[ 'job_hours' ] ) ) {
			update_post_meta( $id, '_job_hours', stripslashes_deep( $_POST[ 'job_hours' ] ) );
		}

		if ( isset( $_POST[ 'geo_latitude' ] ) ) {
			update_post_meta( $id, 'geolocation_lat', stripslashes_deep( $_POST[ 'geo_latitude' ] ) );
		}
		if ( isset( $_POST[ 'geo_longitude' ] ) ) {
			update_post_meta( $id, 'geolocation_long', stripslashes_deep( $_POST[ 'geo_longitude' ] ) );
		}
	}

	public static function get_attachment_id_from_url( $attachment_url = '' ) {

		global $wpdb;
		$attachment_id = false;

		// If there is no url, bail.
		if ( '' == $attachment_url ) {
			return false;
		}

		// Get the upload directory paths
		$upload_dir_paths = wp_upload_dir();

		// Make sure the upload path base directory exists in the attachment URL, to verify that we're working with a media library image
		if ( false !== strpos( $attachment_url, $upload_dir_paths['baseurl'] ) ) {

			// If this is the URL of an auto-generated thumbnail, get the URL of the original image
			$attachment_url = preg_replace( '/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $attachment_url );

			// Remove the upload path base directory from the attachment URL
			$attachment_url = str_replace( $upload_dir_paths['baseurl'] . '/', '', $attachment_url );

			// Finally, run a custom database query to get the attachment ID from the modified attachment URL
			$attachment_id = $wpdb->get_var( $wpdb->prepare( "SELECT wposts.ID FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta WHERE wposts.ID = wpostmeta.post_id AND wpostmeta.meta_key = '_wp_attached_file' AND wpostmeta.meta_value = '%s' AND wposts.post_type = 'attachment'", $attachment_url ) );

		}

		return $attachment_id;
	}

	public static function job_listing_admin_columns( $columns ) {
		if ( ! is_array( $columns ) ) {
			$columns = array();
		}
		unset ( $columns["job_listing_type"] );
		
		return $columns;
	}

	public static function get_job_data( $fields, $job ) {
		$hours = get_post_meta( $job->ID, '_job_hours', true );

		if ( $hours ) {
			$fields[ 'job' ][ 'job_hours' ][ 'value' ] = $hours;
		}

		$gallery_images = get_post_meta( $job->ID, APUSAPUSLISTING_PREFIX.'gallery_images', true );

		if ( $gallery_images ) {
			$fields[ 'company' ][ 'gallery_images' ][ 'value' ] = $gallery_images;
		}
		
		return $fields;
	}

	public static function input_location_fields($key, $field) {
		global $wp_locale, $post, $thepostid;

		$thepostid = $post->ID;
		?>

		<div class="form-field" style="position: relative;">

			<?php if ( ! is_admin() ) : ?>
			<label for="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $field['label'] ) ; ?>:</label>
			<?php endif; ?>

			<?php
			global $field;

			$field[ 'value' ] = get_post_meta( $thepostid, '_job_location', true );
			$field[ 'geo_latitude' ] = get_post_meta( $thepostid, 'geolocation_lat', true );
			$field[ 'geo_longitude' ] = get_post_meta( $thepostid, 'geolocation_long', true );
			
			
			get_job_manager_template( 'form-fields/apuslisting-location-field.php', array('key' => $key, 'field' => $field) );
			?>
		</div>

		<?php
	}

	public static function input_hours_fields() {
		global $wp_locale, $post, $thepostid;

		$thepostid = $post->ID;
		?>

		<div class="form-field" style="position: relative;">

			<?php if ( ! is_admin() ) : ?>
			<label for="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $field['label'] ) ; ?>:</label>
			<?php endif; ?>

			<?php
			global $field;
			if ( empty( $field[ 'value' ] ) ) {
				$field[ 'value' ] = get_post_meta( $thepostid, '_job_hours', true );
			}
			get_job_manager_template( 'form-fields/apuslisting-hours-field.php' );
			?>
			<script>
				(function($) {
					$( '.timepicker' ).timepicker({
						timeFormat: '<?php echo str_replace( '\\', '\\\\', get_option( 'time_format' ) ); ?>',
						noneOption: {
							label: '<?php _e( 'Closed', 'apus-apuslisting' ); ?>',
							value: '<?php _e( 'Closed', 'apus-apuslisting' ); ?>' 
						}
					});
				})(jQuery);
			</script>

		</div>

		<?php
	}

	public static function add_meta_boxes() {
		add_meta_box( 'apusapuslisting_hours', __( 'Hours of Operation', 'apus-apuslisting' ), array( __CLASS__, 'admin_hours' ), 'job_listing', 'side', 'low' );
	}

	public static function admin_hours() {
		do_action( 'job_manager_input_apuslisting_hours', '_job_hours', array(
			'label' => __( 'Hours of Operation', 'apus-apuslisting' ),
			'type' => 'apuslisting_hours',
			'placeholder' => '',
			'priority' => 99
		) );
	}
}

ApusApusListing_Post_Type_Job_Listing::init();