;(function ($, window, undefined) {
    // outside the scope of the jQuery plugin to
    // keep track of all dropdowns
    var $allDropdowns = $();

    // if instantlyCloseOthers is true, then it will instantly
    // shut other nav items when a new one is hovered over
    $.fn.dropdownHover = function (options) {
        // don't do anything if touch is supported
        // (plugin causes some issues on mobile)
        if('ontouchstart' in document) return this; // don't want to affect chaining

        // the element we really care about
        // is the dropdown-toggle's parent
        $allDropdowns = $allDropdowns.add(this.parent());

        return this.each(function () {
            var $this = $(this),
                $parent = $this.parent(),
                defaults = {
                    delay: 500,
                    hoverDelay: 0,
                    instantlyCloseOthers: true
                },
                data = {
                    delay: $(this).data('delay'),
                    hoverDelay: $(this).data('hover-delay'),
                    instantlyCloseOthers: $(this).data('close-others')
                },
                showEvent   = 'show.bs.dropdown',
                hideEvent   = 'hide.bs.dropdown',
                // shownEvent  = 'shown.bs.dropdown',
                // hiddenEvent = 'hidden.bs.dropdown',
                settings = $.extend(true, {}, defaults, options, data),
                timeout, timeoutHover;

            $parent.hover(function (event) {
                // so a neighbor can't open the dropdown
                if(!$parent.hasClass('open') && !$this.is(event.target)) {
                    // stop this event, stop executing any code
                    // in this callback but continue to propagate
                    return true;
                }

                openDropdown(event);
            }, function () {
                // clear timer for hover event
                window.clearTimeout(timeoutHover)
                timeout = window.setTimeout(function () {
                    $this.attr('aria-expanded', 'false');
                    $parent.removeClass('open');
                    $this.trigger(hideEvent);
                }, settings.delay);
            });

            // this helps with button groups!
            $this.hover(function (event) {
                // this helps prevent a double event from firing.
                // see https://github.com/CWSpear/bootstrap-hover-dropdown/issues/55
                if(!$parent.hasClass('open') && !$parent.is(event.target)) {
                    // stop this event, stop executing any code
                    // in this callback but continue to propagate
                    return true;
                }

                openDropdown(event);
            });

            // handle submenus
            $parent.find('.dropdown-submenu').each(function (){
                var $this = $(this);
                var subTimeout;
                $this.hover(function () {
                    window.clearTimeout(subTimeout);
                    $this.children('.dropdown-menu').show();
                    // always close submenu siblings instantly
                    $this.siblings().children('.dropdown-menu').hide();
                }, function () {
                    var $submenu = $this.children('.dropdown-menu');
                    subTimeout = window.setTimeout(function () {
                        $submenu.hide();
                    }, settings.delay);
                });
            });

            function openDropdown(event) {
                // clear dropdown timeout here so it doesnt close before it should
                window.clearTimeout(timeout);
                // restart hover timer
                window.clearTimeout(timeoutHover);
                
                // delay for hover event.  
                timeoutHover = window.setTimeout(function () {
                    $allDropdowns.find(':focus').blur();

                    if(settings.instantlyCloseOthers === true)
                        $allDropdowns.removeClass('open');
                    
                    // clear timer for hover event
                    window.clearTimeout(timeoutHover);
                    $this.attr('aria-expanded', 'true');
                    $parent.addClass('open');
                    $this.trigger(showEvent);
                }, settings.hoverDelay);
            }
        });
    };

    $(document).ready(function () {
        // apply dropdownHover to all elements with the data-hover="dropdown" attribute
        $('[data-hover="dropdown"]').dropdownHover();
          //  Fix First Click Menu /

    });
    $(document.body).on('click', '.nav [data-toggle="dropdown"]' ,function(){
      	if(  this.href && this.href != '#'){
          	window.location.href = this.href;
      	}
    });

})(jQuery, window);


jQuery.fn.wrapStart = function(numWords){
    return this.each(function(){
        var $this = $(this);
        var node = $this.contents().filter(function(){
            return this.nodeType == 3;
        }).first(),
        text = node.text().trim(),
        first = text.split(' ', 1).join(" ");
        if (!node.length) return;
        node[0].nodeValue = text.slice(first.length);
        node.before('<b>' + first + '</b>');
    });
};

jQuery( document).ready( function($){
    
    $('.mod-heading .widget-title > span').wrapStart(1);
    function init_owl() {
        $(".owl-carousel[data-carousel=owl]").each( function(){
            var config = {
                loop: false,
                nav: $(this).data( 'nav' ),
                dots: $(this).data( 'pagination' ),
                items: 4,
                autoplayTimeout:2000,
                autoplayHoverPause:false,
                navText: ['<span class="icon-angle-left"></span>', '<span class="icon-angle-right"></span>']
            };
        
            var owl = $(this);
            if( $(this).data('items') ){
                config.items = $(this).data( 'items' );
            }
            if( $(this).data('loop') ){
                config.loop = true;
            }
            if( $(this).data('autoplay') ){
                config.autoplay = true;
                config.autoplayHoverPause = true;
            }
            if( $(this).data('margin') || $(this).data('margin') == 0){
                config.margin = $(this).data( 'margin' );
            } else {
                config.margin = 30;
            }
            if( $(this).data('autoplayTimeout') ){
                config.autoplayTimeout = $(this).data('autoplayTimeout');
            }
            if ($(this).data('large')) {
                var desktop = $(this).data('large');
            } else {
                var desktop = config.items;
            }
            if ($(this).data('medium')) {
                var medium = $(this).data('medium');
            } else {
                var medium = config.items;
            }
            if ($(this).data('smallmedium')) {
                var smallmedium = $(this).data('smallmedium');
            } else {
                var smallmedium = config.items;
            }
            if ($(this).data('extrasmall')) {
                var extrasmall = $(this).data('extrasmall');
            } else {
                var extrasmall = 2;
            }
            if ($(this).data('verysmall')) {
                var verysmall = $(this).data('verysmall');
            } else {
                var verysmall = 1;
            }
            config.responsive = {
                0:{
                    items:verysmall
                },
                481:{
                    items:extrasmall
                },
                768:{
                    items:smallmedium
                },
                980:{
                    items:medium
                },
                1280:{
                    items:desktop
                }
            }
            if ( $('html').attr('dir') == 'rtl' ) {
                config.rtl = true;
            }
            $(this).owlCarousel( config );
            // owl enable next, preview
            var viewport = jQuery(window).width();
            var itemCount = jQuery(".owl-item", $(this)).length;

            if(
                (viewport >= 1280 && itemCount <= desktop) //desktop
                || ((viewport >= 980 && viewport < 1280) && itemCount <= medium) //desktop
                || ((viewport >= 768 && viewport < 980) && itemCount <= smallmedium) //tablet
                || ((viewport >= 320 && viewport < 768) && itemCount <= extrasmall) //mobile
                || (viewport < 320 && itemCount <= verysmall) //mobile
            ) {
                $(this).find('.owl-prev, .owl-next').hide();
            }
        } );
    }
    init_owl();
    // Fix owl in bootstrap tabs
    $('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
        initProductImageLoad();
        var target = $(e.target).attr("href");
        var carousel = $(".owl-carousel[data-carousel=owl]", target).data('owlCarousel');

        if ($(".owl-carousel[data-carousel=owl]", target).length > 0) {
            carousel._width = $(".owl-carousel[data-carousel=owl]", target).width();
            carousel.invalidate('width');
            carousel.refresh();
        }
    });
    if ($(".entry-featured-carousel .owl-carousel .photo-item").length > 2 ) {
        $(".entry-featured-carousel .owl-carousel").trigger("to.owl.carousel", [1, 1, true]);
    }


    
    setTimeout(function(){
        initProductImageLoad();
    },500);
    function initProductImageLoad() {
        $(window).off('scroll.unveil resize.unveil lookup.unveil');
        var $images = $('.image-wrapper:not(.image-loaded) .unveil-image'); // Get un-loaded images only
        if ($images.length) {
            var scrollTolerance = 1;
            $images.unveil(scrollTolerance, function() {
                $(this).load(function() {
                    $(this).parents('.image-wrapper').first().addClass('image-loaded');
                });
            });
        }

        var $images = $('.product-image:not(.image-loaded) .unveil-image'); // Get un-loaded images only
        if ($images.length) {
            var scrollTolerance = 1;
            $images.unveil(scrollTolerance, function() {
                $(this).load(function() {
                    $(this).parents('.image-wrapper').first().addClass('image-loaded');
                });
            });
        }
    }
    // search form
    $('.search-form-action').click(function(){
        $('.apus-search-form').slideToggle("fast");
        initProductImageLoad();
    });
    $('.button-search-close').click(function(){
        $('.apus-search-form').slideToggle("fast");
    });
    $('.view-photo-action').click(function(e){
        e.preventDefault();
        $('.more-photos').toggleClass('hidden');
        $('.view-photo-action').removeClass('hidden');
        $(this).addClass('hidden');
        initProductImageLoad();
    });
    $('.search-form-action').click(function(){
        if ( $(this).find('i').hasClass('icon-search') ) {
            $(this).find('i').removeClass('icon-search').addClass('icon-close');
        } else {
            $(this).find('i').removeClass('icon-close').addClass('icon-search');
        }
    });


    //counter up
    if($('.counterUp').length > 0){
        $('.counterUp').counterUp({
            delay: 10,
            time: 800
        });
    }

    /*---------------------------------------------- 
     * Play Isotope masonry
     *----------------------------------------------*/  
    jQuery('.isotope-items,.blog-masonry').each(function(){  
        var $container = jQuery(this);
        
        $container.isotope({
            itemSelector : '.isotope-item',
            transformsEnabled: true         // Important for videos
        });
    });
    /*---------------------------------------------- 
     *    Apply Filter        
     *----------------------------------------------*/
    jQuery('.isotope-filter li a').on('click', function(){
       
        var parentul = jQuery(this).parents('ul.isotope-filter').data('related-grid');
        jQuery(this).parents('ul.isotope-filter').find('li a').removeClass('active');
        jQuery(this).addClass('active');
        var selector = jQuery(this).attr('data-filter'); 
        jQuery('#'+parentul).isotope({ filter: selector }, function(){ });
        
        return(false);
    });

    //Sticky Header
    if ($('body.fix-header').length <= 0) {
        setTimeout(function(){
            change_margin_top();
        }, 200);
        $(window).resize(function(){
            change_margin_top();
        });
        function change_margin_top() {
            if ($(window).width() > 991) {
                if ( $('.main-sticky-header').length > 0 ) {
                    var header_height = $('.main-sticky-header').outerHeight();
                    $('.main-sticky-header-wrapper').css({'height': header_height});
                }
            }
        }
        var main_sticky = $('.main-sticky-header');
        
        if ( main_sticky.length > 0 ){
            var _menu_action = main_sticky.offset().top;
            var Apus_Menu_Fixed = function(){
                "use strict";

                if( $(document).scrollTop() > _menu_action ){
                  main_sticky.addClass('sticky-header');
                }else{
                  main_sticky.removeClass('sticky-header');
                }
            }
            if ($(window).width() > 991) {
                $(window).scroll(function(event) {
                    Apus_Menu_Fixed();
                });
                Apus_Menu_Fixed();
            }
        }
    }

    //Tooltip
    $(function () {
      $('[data-toggle="tooltip"]').tooltip()
    })

    $('.topbar-mobile .dropdown-menu').on('click', function(e) {
      	e.stopPropagation();
    });

    var back_to_top = function () {
        jQuery(window).scroll(function () {
            if (jQuery(this).scrollTop() > 400) {
                jQuery('#back-to-top').addClass('active');
            } else {
                jQuery('#back-to-top').removeClass('active');
            }
        });
        jQuery('#back-to-top').on('click', function () {
            jQuery('html, body').animate({scrollTop: '0px'}, 800);
            return false;
        });
    };
    back_to_top();
    
    // popup
    $(document).ready(function() {
        $(".popup-image").magnificPopup({type:'image'});
        $('.popup-video').magnificPopup({
            disableOn: 700,
            type: 'iframe',
            mainClass: 'mfp-fade',
            removalDelay: 160,
            preloader: false,
            fixedContentPos: false
        });

        $('.listing-photos').magnificPopup({
            delegate: '.photo-item',
            type: 'image',
            tLoading: 'Loading image #%curr%...',
            mainClass: 'mfp-img-mobile',
            gallery: {
                enabled: true,
                navigateByImgClick: true,
                preload: [0,1] // Will preload 0 - before current, and 1 after the current image
            }
        });
        $('.comment-attactments').each(function(){
            var tagID = $(this).attr('id');
            $('#' + tagID).magnificPopup({
                delegate: '.photo-item',
                type: 'image',
                tLoading: 'Loading image #%curr%...',
                mainClass: 'mfp-img-mobile',
                gallery: {
                    enabled: true,
                    navigateByImgClick: true,
                    preload: [0,1] // Will preload 0 - before current, and 1 after the current image
                }
            });
        });
        
    });    
    // widget search jobs
    $(".search_jobs .show-more-filter").click(function(e){
        e.preventDefault();
        $(".search_jobs .amenities-wrap").toggle('500');
        if($(this).find('i').hasClass('icon-add')){
            $(this).find('i').removeClass('icon-add');
            $(this).find('i').addClass('icon-minimize');
        } else {
            $(this).find('i').removeClass('icon-minimize');
            $(this).find('i').addClass('icon-add');
        }
    });
    $('.job_search_form .has-suggestion').click(function(e) {
        e.stopPropagation();
    });
    $(".job_search_form .has-suggestion").click(function(){
        $(this).toggleClass("active");
    });
    $('body').click(function() {
        if ($('.job_search_form .has-suggestion').hasClass('active')) {
            $('.job_search_form .has-suggestion').removeClass('active');
        }
    });
    // edit profile
    $('.change-profile-form .wrapper-select').click(function(e) {
        e.stopPropagation();
    });
    $(".change-profile-form .wrapper-select").click(function(){
        $(this).toggleClass("active");
    });
    $('body').click(function() {
        if ($('.change-profile-form .wrapper-select').hasClass('active')) {
            $('.change-profile-form .wrapper-select').removeClass('active');
        }
    });
    // login/register
    $('.apus-user-login, .apus-user-register').click(function(){
        var target = $(this).attr('href');
        $(target).click();
        $('.apus_login_register_form .nav-tabs li').removeClass('active');
        $(target).parent().addClass('active');
        var id = $(target).attr('href');
        $('.apus_login_register_form .tab-pane').removeClass('active');
        $(id).addClass('active').addClass('in');

        $.magnificPopup.open({
            mainClass: 'apus-mfp-zoom-in',
            items    : {
                src : $('#apus_login_register_form_wrapper').html(),
                type: 'inline'
            }
        });
        return false;
    });
    $('body').on('click', '.apus_login_register_form .mfp-close', function(){
        $.magnificPopup.close();
    });

    $('#apus_forgot_password_form').hide();
    $('#apus_login_form form .btn-cancel').on('click', function(){  
        $('#apus_login_form').hide();
    } );
    
    // sign in proccess
    $('body').on('submit', 'form.apus-login-form', function(){
        var $this= $(this);
        $('.alert', this).remove(); 
        $.ajax({
            url: apuslisting_ajax.ajaxurl,
            type:'POST',
            dataType: 'json',
            data:  $(this).serialize()+"&action=apus_ajax_login"
        }).done(function(data) {
            if ( data.loggedin ) {
                $this.prepend( '<div class="alert alert-info">' + data.msg + '</div>' );
                location.reload(); 
            } else {
                $this.prepend( '<div class="alert alert-warning">' + data.msg + '</div>' );
            }
        });
        return false; 
    } );
    $('body').on('click', '.back-link', function(){
        $('.form-container').hide();
        $($(this).attr('href')).show(); 
        return false;
    } );

     // lost password in proccess
    $('body').on('submit', 'form.forgotpassword-form', function(){
        var $this= $(this);
        $('.alert', this).remove(); 
        $.ajax({
          url: apuslisting_ajax.ajaxurl,
          type:'POST',
          dataType: 'json',
          data:  $(this).serialize()+"&action=apus_ajax_forgotpass"
        }).done(function(data) {
            if ( data.loggedin ) {
                $this.prepend( '<div class="alert alert-info">'+data.msg+'</div>' );
                location.reload(); 
            } else {
                $this.prepend( '<div class="alert alert-warning">'+data.msg+'</div>' );
            }
        });
        return false; 
    } );
    $('body').on('click', '#apus_forgot_password_form form .btn-cancel', function(){
        $('#apus_forgot_password_form').hide();
        $('#apus_login_form').show();
    } );

    // register
    $('body').on('submit', 'form.apus-register-form', function(){
        var $this= $(this);
        $('.alert', this).remove(); 
        $.ajax({
          url: apuslisting_ajax.ajaxurl,
          type:'POST',
          dataType: 'json',
          data:  $(this).serialize()+"&action=apus_ajax_register"
        }).done(function(data) {
            if ( data.loggedin ) {
                $this.prepend( '<div class="alert alert-info">'+data.msg+'</div>' );
                location.reload();
            } else {
                $this.prepend( '<div class="alert alert-warning">'+data.msg+'</div>' );
            }
        });
        return false;
    } );

    // mobile menu
    $('[data-toggle="offcanvas"], .btn-offcanvas').on('click', function (e) {
        e.stopPropagation();
        $('#wrapper-container').toggleClass('active');
        $('#apus-mobile-menu').toggleClass('active');           
    });
    
    $('body').click(function() {
        if ($('#wrapper-container').hasClass('active')) {
            $('#wrapper-container').toggleClass('active');
            $('#apus-mobile-menu').toggleClass('active');
        }
    });
    $('#apus-mobile-menu').click(function(e) {
        e.stopPropagation();
    });
    $("#main-mobile-menu .icon-toggle").on('click', function(){
        $(this).parent().find('> .sub-menu').slideToggle();
        if ( $(this).find('i').hasClass('fa-plus') ) {
            $(this).find('i').removeClass('fa-plus').addClass('fa-minus');
        } else {
            $(this).find('i').removeClass('fa-minus').addClass('fa-plus');
        }
        return false;
    } );

    // preload page
    var $body = $('body');
    if ( $body.hasClass('apus-body-loading') ) {

        setTimeout(function() {
            $body.removeClass('apus-body-loading');
            $('.apus-page-loading').fadeOut(250);
        }, 200);
    }

    // favorite
    $( "body" ).on( "click", ".apus-favorite-add", function( e ) {
        e.preventDefault();

        var post_id = $(this).data('id');
        var url = apuslisting_ajax.ajaxurl + '?action=apuslisting_add_favorite&post_id=' + post_id;
        var self = $(this);
        self.addClass('loading');
        $.ajax({
            url: url,
            type:'POST',
            dataType: 'json',
        }).done(function(reponse) {
            if (reponse.icon) {
                self.parent().html(reponse.icon);
            } else {
                $.magnificPopup.open({
                    mainClass: 'apus-mfp-zoom-small-in',
                    items : {
                        src : reponse.msg,
                        type: 'inline'
                    }
                });
            }
            self.removeClass('loading');
        });
    });

    $( "body" ).on( "click", ".apus-favorite-not-login", function( e ) {
        e.preventDefault();
        //$('.apus-user-login').click();
        var target = $('.apus-user-login').attr('href');
        $(target).click();
        $('.apus_login_register_form .nav-tabs li').removeClass('active');
        $(target).parent().addClass('active');
        var id = $(target).attr('href');
        $('.apus_login_register_form .tab-pane').removeClass('active');
        $(id).addClass('active').addClass('in');

        $.magnificPopup.open({
            mainClass: 'apus-mfp-zoom-in',
            items    : {
                src : $('#apus_login_register_form_wrapper').html(),
                type: 'inline'
            }
        });
    });
    // favorite
    $( "body" ).on( "click", ".apus-favorite-remove", function( e ) {
        e.preventDefault();

        var post_id = $(this).data('id');
        var url = apuslisting_ajax.ajaxurl + '?action=apuslisting_remove_favorite&post_id=' + post_id;
        var self = $(this);
        self.addClass('loading');
        $.ajax({
            url: url,
            type:'POST',
            dataType: 'json',
        }).done(function(reponse) {
            if (reponse.status) {
                var parent = $('#favorite-listing-' + post_id).parent();
                if ( $('.my-listing-item-wrapper', parent).length <= 1 ) {
                    location.reload();
                } else {
                    $('#favorite-listing-' + post_id).remove();
                }
            } else {
                $.magnificPopup.open({
                    mainClass: 'apus-mfp-zoom-small-in',
                    items: {
                        src : reponse.msg,
                        type: 'inline'
                    }
                });
            }
        });
    });
    
    // listing
    // fix map
    function change_padding_top_mobile_content() {
        if ($(window).width() >= 992) {
            var header_h = 0;
        } else {
            var header_h = $('#apus-header-mobile').outerHeight();
        }
        $('#apus-main-content').css({ 'padding-top': header_h });
    }
    setTimeout(function(){
        change_padding_top_mobile_content();
    }, 100);
    $(window).resize(function(){
        change_padding_top_mobile_content();
    });
    if ($('#apus-listing-map').is('.fix-map')) {
        function change_padding_top_content() {
            if ($(window).width() >= 992) {
                var header_h = $('#apus-header').outerHeight();
            } else {
                var header_h = $('#apus-header-mobile').outerHeight();
            }
            $('#apus-listing-map').css({ 'top': header_h });
            $('#apus-main-content').css({ 'padding-top': header_h });
        }
        setTimeout(function(){
            change_padding_top_content();
        }, 100);
        $(window).resize(function(){
            change_padding_top_content();
        });
    }
    // if ($('.wrapper-filters .job_filters .search_jobs').length) {
    //     function change_search_job() {
    //         if ($(window).width() >= 992) {
    //             $('.job_filters .search_jobs').css({'display': 'block'});
    //         } else {
    //             $('.job_filters .search_jobs').css({'display': 'none'});
    //         }
    //     }
    //     change_search_job();
    //     $(window).resize(function(){
    //         change_search_job();
    //     });
    // }
    // listing review
    if ( $('.comment-form-rating').length > 0 ) {
        var $star = $('.comment-form-rating .filled');
        var $review = $('#apus_input_rating');
        $star.find('li').on('mouseover',
            function () {
                $(this).nextAll().find('span').removeClass('icon-star').addClass('icon-star-out-line');
                $(this).prevAll().find('span').removeClass('icon-star-out-line').addClass('icon-star');
                $(this).find('span').removeClass('icon-star-out-line').addClass('icon-star');
                $review.val($(this).index() + 1);
            }
        );
    }
    // maps filters
    if ( window.history && window.history.pushState ) {
        $supports_html5_history = true;
    } else {
        $supports_html5_history = false;
    }

    // chosen
    if ( $.isFunction( $.fn.select2 ) && typeof job_manager_select2_args !== 'undefined' ) {
        var select2_args = job_manager_select2_args;
        select2_args['allowClear']              = true;
        select2_args['minimumResultsForSearch'] = 10;
        if ( $('html').attr('dir') == 'rtl' ) {
            select2_args.dir = 'rtl';
        }
        $( 'select[name^="job_region_select"]' ).select2( select2_args );
        $( 'select[name^="job_regions"]' ).select2( select2_args );
        
        $( 'select[name^="search_categories"]' ).select2( select2_args );
        // $( 'select[name^="job_region_select"]' ).select2( select2_args );
    }
    $('.job_filters select[name=job_region_select]').change(function(){
        $('.job_listings').triggerHandler( 'update_results', [ 1, false ] );
        var target = $('.job_listings');
        if ( $supports_html5_history ) {
            var form  = target.find( '.job_filters' );
            var data  = $( form ).serialize();
            var index = $( 'div.job_listings' ).index( target );
            window.history.replaceState( { id: 'job_manager_state', page: 1, data: data, index: index }, '', location + '#s=1' );
        }
    });

    // anienties
    var updateAmenities = function() {
        $( '.job_amenities :input' ).change( function() {
            $( this ).parent().toggleClass('active');
            var target   = $( this ).closest( 'div.job_listings' );
            target.triggerHandler( 'update_results', [ 1, false ] );
        } );
    };
    updateAmenities();
    $( '.job_amenities :input' ).each( function() {
        if ($(this).is(':checked') ) {
            $( this ).parent().addClass('active');
        } else {
            $( this ).parent().removeClass('active');
        }
    });
    var $displayMode = $('.listing-display-mode .display-mode .change-view'),
        updateDisplayMode = function() {
            $displayMode.click(function(e){
                e.preventDefault();
                var value = $(this).data('mode');
                setCookie('apuslisting_display_mode', value, 30);
                $('.input_display_mode').val(value);
                $displayMode.removeClass('active');
                $(this).addClass('active');
                $('.job_listings').triggerHandler('update_results', [1, false]);
            });
        },
        updateOrderBy = function() {
            $('.listing-orderby select').change(function(){
                var value = $(this).val();
                setCookie('apuslisting_order', value, 30);
                $('.input_filter_oder').val(value);
                $('.job_listings').triggerHandler('update_results', [1, false]);
            });
        };
    updateDisplayMode();
    updateOrderBy();

    $('#search-distance-slider').slider({
        range: "min",
        value: $('#search_distance').val(),
        min: 0,
        max: 100,
        slide: function( event, ui ) {
            $( "#search_distance" ).val( ui.value );
            $('.text-distance').text( ui.value );

            $('.job_listings').triggerHandler('update_results', [1, false]);
        }
    } );

    $.fn.bindFirst = function(name, selector, fn) {
        // bind as you normally would
        // don't want to miss out on any jQuery magic
        this.on(name, selector, fn);

        // Thanks to a comment by @Martin, adding support for
        // namespaced events too.
        this.each(function() {
            var handlers = $._data(this, 'events')[name.split('.')[0]];
            // take out the handler we just inserted from the end
            var handler = handlers.pop();
            // move it at the beginning
            handlers.splice(0, 0, handler);
        });
    };

    $('.job_filters').bindFirst('click', '.reset', function() {
        $('.job_amenities').find(':checked').each(function(i, obj) {
            $(obj).attr('checked', false);
        });
        $('.job_amenities input').trigger('change.select2');

        $('.regions-select').find(':selected').each(function(i, obj) {
            $(obj).attr('selected', false);
        });
        $('.regions-select').trigger('change.select2');
        
        $('input[name="search_keywords"]').each(function(i, obj) {
            $(obj).val('').trigger('change.select2');
        });
    });

    if ($('.detail-haft-map').length > 0) {
        $('body').addClass( 'no-breadscrumb no-footer fix-header' );
    }
    if ($('.detail-full-gallery').length > 0 || $('.detail-full-map').length > 0) {
        $('body').addClass( 'no-breadscrumb' );
    }

    // write-a-review
    $('.write-a-review').click(function(e){
        e.preventDefault();
        $('html, body').animate({
            scrollTop: $("#review_form_wrapper").offset().top
        }, 1000);
    });

    $('.btn-show-filter').click(function(e){
        e.preventDefault();
        if ( $('.job_filters .search_jobs').hasClass('active') ) {
            $('.job_filters .search_jobs').removeClass('active');
        } else {
            $('.job_filters .search_jobs').addClass('active');
        }
    });
    $('.btn-view-map').click(function(e){
        e.preventDefault();
        $('.apus-listing-map').removeClass('hidden-sm').removeClass('hidden-xs');
        $('.apus-listing-warpper .job_listings').addClass('hidden-sm').addClass('hidden-xs');
        $('.btn-view-listing').removeClass('hidden-sm').removeClass('hidden-xs');
        $(this).addClass('hidden-sm').addClass('hidden-xs');
        $('.showing_jobs').addClass('hidden-sm').addClass('hidden-xs');
        $('.listing-action').addClass('hidden-sm').addClass('hidden-xs');
        setTimeout(function() {
            $(window).trigger('pxg:refreshmap');
        });
    });
    $('.btn-view-listing').click(function(e){
        e.preventDefault();
        $('.apus-listing-map').addClass('hidden-sm').addClass('hidden-xs');
        $('.apus-listing-warpper .job_listings').removeClass('hidden-sm').removeClass('hidden-xs');
        $('.btn-view-map').removeClass('hidden-sm').removeClass('hidden-xs');
        $(this).addClass('hidden-sm').addClass('hidden-xs');
        $('.showing_jobs').removeClass('hidden-sm').removeClass('hidden-xs');
        $('.listing-action').removeClass('hidden-sm').removeClass('hidden-xs');
    });
    $('.sharing-popup .share-popup').click(function(e){
        e.preventDefault();
        $(this).parent().toggleClass('active');
    });

    $( '.timepicker' ).timepicker({
        timeFormat: apuslisting_ajax.time_format,
        noneOption: {
            label: apuslisting_ajax.closed_text,
            value: apuslisting_ajax.closed_text
        }
    });

    // sticky tabs
    var affix_height = 0;
    var affix_height_top = 0;
    setTimeout(function(){
        change_margin_top_affix();
    }, 50);
    $(window).resize(function(){
        change_margin_top_affix();
    });

    function change_margin_top_affix() {
        if ($(window).width() > 991) {
            if ( $('.panel-affix').length > 0 ) {
                affix_height_top = affix_height = $('.panel-affix').outerHeight();
                $('.panel-affix-wrapper').css({'height': affix_height});
            }
        }
    }
    //Function from Bluthemes, lets you add li elemants to affix object without having to alter and data attributes set out by bootstrap
    
    // name your elements here
    var stickyElement   = '.panel-affix',   // the element you want to make sticky
        bottomElement   = '#apus-footer'; // the bottom element where you want the sticky element to stop (usually the footer) 

    // make sure the element exists on the page before trying to initalize
    if($( stickyElement ).length){
        $( stickyElement ).each(function(){
            var header_height = 0;
            if ($('.main-sticky-header').length > 0) {
                header_height = $('.main-sticky-header').outerHeight();
                affix_height_top = affix_height + header_height;
            }
            // let's save some messy code in clean variables
            // when should we start affixing? (the amount of pixels to the top from the element)
            var fromTop = $( this ).offset().top, 
                // where is the bottom of the element?
                fromBottom = $( document ).height()-($( this ).offset().top + $( this ).outerHeight()),
                // where should we stop? (the amount of pixels from the top where the bottom element is)
                // also add the outer height mismatch to the height of the element to account for padding and borders
                stopOn = $( document ).height()-( $( bottomElement ).offset().top)+($( this ).outerHeight() - $( this ).height()); 

            // if the element doesn't need to get sticky, then skip it so it won't mess up your layout
            if( (fromBottom-stopOn) > 200 ){
                // let's put a sticky width on the element and assign it to the top
                $( this ).css('width', $( this ).width()).css('top', 0).css('position', '');
                // assign the affix to the element
                $( this ).affix({
                    offset: { 
                        // make it stick where the top pixel of the element is
                        top: fromTop - header_height,  
                        // make it stop where the top pixel of the bottom element is
                        bottom: stopOn
                    }
                // when the affix get's called then make sure the position is the default (fixed) and it's at the top
                }).on('affix.bs.affix', function(){
                    var header_height = 0;
                    if ($('.main-sticky-header').length > 0) {
                        header_height = $('.main-sticky-header').outerHeight();
                    }
                    affix_height_top = affix_height + header_height;
                    $( this ).css('top', header_height).css('position', '');
                });
            }
            // trigger the scroll event so it always activates 
            $( window ).trigger('scroll'); 
        }); 
    }


    //Offset scrollspy height to highlight li elements at good window height
    $('body').scrollspy({
        offset: 80
    });

    //Smooth Scrolling For Internal Page Links
      $('.panel-affix a[href*="#"]:not([href="#"])').click(function() {
        if (location.pathname.replace(/^\//,'') == this.pathname.replace(/^\//,'') && location.hostname == this.hostname) {
          var target = $(this.hash);
          target = target.length ? target : $('[name=' + this.hash.slice(1) +']');
          if (target.length) {
            $('html,body').animate({
              scrollTop: target.offset().top - affix_height_top
            }, 1000);
            return false;
          }
        }
      });
    // smooth scrolling when click a link
    $(document).on('click', '.panel-affix a[href*="#"]:not([href="#"])', function(event){
        event.preventDefault();
        $('html, body').animate({
            scrollTop: $( $.attr(this, 'href') ).offset().top
        }, 500);
    });

    // file attachments
    $('#field_attachments_cover').click(function(){
        $("#field_attachments").click();
    });
    var imagesPreview = function(input, placeToInsertImagePreview) {
        if (input.files) {
            var filesAmount = input.files.length;
            for (i = 0; i < filesAmount; i++) {
                var reader = new FileReader();
                reader.onload = function(event) {
                    $($.parseHTML('<img>')).attr('src', event.target.result).appendTo(placeToInsertImagePreview);
                }
                reader.readAsDataURL(input.files[i]);
            }
        }
    };
    $('#field_attachments').on('change', function() {
        $('.group-upload-preview').html('');
        imagesPreview(this, 'div.group-upload-preview');
        $('.group-upload-preview').css("display","block");
    });

    $('.comment-attactments').each(function(){
        var self = $(this);
        $('.show-more-images', self).click(function(){
            $('.attachment', self).removeClass('hidden');
            $(this).addClass('hidden');
            initProductImageLoad();
        });
    });
    $('.comment-actions .comment-like').click(function(e){
        e.preventDefault();
        var self = $(this);
        self.addClass('loading');

        $.ajax({
            url: apuslisting_ajax.ajaxurl,
            type:'POST',
            dataType: 'html',
            data:  "action=apuslisting_comment_like&comment_id="+self.data('id')
        }).done(function(data) {
            self.removeClass('loading');
            self.html(data);
            self.toggleClass('active');
        });
    });

    $('.comment-actions .comment-report:not(.open)').click(function(e){
        e.preventDefault();
        var self = $(this);
        if ( self.hasClass('open') ) {
            return false;
        }
        self.addClass('open');
        var html = $('<div>' + $('.report-comment-form-hidden').html() + '</div>')
        var tagID = self.attr('href');
        var comment_id = self.data('id');
        html.find('.report_comment_id').val(comment_id);
        $(tagID).html(html);
        $('.cancel-report', html).click(function(){
            $(tagID).html('');
            self.removeClass('open');
        });
        $('form.apus-report-comment-form', html).submit(function(e){
            e.preventDefault();
            var self_form = $(this);
            self_form.addClass('loading');
            $.ajax({
                url: apuslisting_ajax.ajaxurl,
                type:'POST',
                dataType: 'html',
                data:  self_form.serialize() + "&action=apuslisting_comment_report"
            }).done(function(data) {
                self_form.removeClass('loading');
                self_form.find('.msg').html(data);
            });
        });
    });
    //
    $('.comment-box').each(function(){
        var self = $(this);
        $('.comment-see-more', self).click(function(){
            $('.comment-text', self).slideToggle();
            $('.title-job', self).toggleClass("active");
            initProductImageLoad();
        });
    });
    
    // follow/following
    $( "body" ).on( "click", ".btn-follow-following", function( e ) {
        e.preventDefault();

        var user_id = $(this).data('id');
        var self = $(this);
        if ( self.hasClass('loading') ) {
            return false;
        }
        self.addClass('loading');
        $.ajax({
            url: apuslisting_ajax.ajaxurl,
            type:'POST',
            dataType: 'json',
            data: {
                'action': 'apuslisting_follow_user',
                'user_id': user_id
            }
        }).done(function(response) {
            if ( response.status === 'error' ) {
                alert( response.msg );
            } else {
                self.removeClass('btn-follow-user').removeClass('btn-following-user').addClass(response.class);
                if ( self.hasClass('btn-outline') ) {
                    self.removeClass('btn-outline');
                } else {
                    self.addClass('btn-outline');
                }
                self.html(response.msg);
            }
            self.removeClass('loading');
        });
    });
    // user profile edit
    if ( $('#change-profile-form-birthday').length > 0 ) {
        $('#change-profile-form-birthday').datepicker({
               defaultDate: "",
               dateFormat: "dd/mm/yy",
               numberOfMonths: 1,
               showButtonPanel: true,
        });
    }
    $('form.change-profile-form').submit(function(e){
        e.preventDefault();
        var self_form = $(this);
        self_form.addClass('loading');
        $.ajax({
            url: apuslisting_ajax.ajaxurl,
            type:'POST',
            dataType: 'json',
            data:  self_form.serialize() + "&action=apuslisting_process_change_profile_form"
        }).done(function(data) {
            self_form.removeClass('loading');
            self_form.find('.msg').html(data.msg);
        });
    });
    var isAdvancedUpload = function() {
        var div = document.createElement('div');
        return (('draggable' in div) || ('ondragstart' in div && 'ondrop' in div)) && 'FormData' in window && 'FileReader' in window;
    }();

    if (isAdvancedUpload) {

        var droppedFiles = false;
        $('.label-can-drag').each(function(){
            var label_self = $(this);
            label_self.on('drag dragstart dragend dragover dragenter dragleave drop', function(e) {
                e.preventDefault();
                e.stopPropagation();
            }).on('dragover dragenter', function() {
                label_self.addClass('is-dragover');
            }).on('dragleave dragend drop', function() {
                label_self.removeClass('is-dragover');
            }).on('drop', function(e) {
                droppedFiles = e.originalEvent.dataTransfer.files;
                label_self.parent().find('input[type="file"]').prop('files', droppedFiles).trigger('change');
            });
        });
    }

    $( document.body ).on( 'click', '.job-manager-remove-uploaded-file', function() {
        $(this).closest( '.job-manager-uploaded-file' ).remove();
        return false;
    });

    
    // user change pass
    $('form.change-password-form').submit(function(e){
        e.preventDefault();
        var self_form = $(this);
        self_form.addClass('loading');
        $.ajax({
            url: apuslisting_ajax.ajaxurl,
            type:'POST',
            dataType: 'json',
            data:  self_form.serialize() + "&action=apuslisting_process_change_password"
        }).done(function(data) {
            self_form.removeClass('loading');
            self_form.find('.msg').html(data.msg);
        });
    });
    $('.btn-contact').click(function(e){
        e.preventDefault();
        jQuery('html, body').animate({ scrollTop: jQuery($(this).attr('href')).offset().top}, 500, 'linear');
    });
    
    $('.search_price_range input[type=checkbox]').each(function(){
        if ( $(this).is(':checked') ) {
            $(this).parent().addClass('active');
        }
    });
    $('.search_price_range label').click(function(e){
        e.preventDefault();
        $(this).toggleClass('active');
        if ( $(this).find('input[type=checkbox]').is(':checked') ) {
            $(this).find('input[type=checkbox]').prop('checked', false);
        } else {
            $(this).find('input[type=checkbox]').attr( 'checked', 'checked' );
        }
        jQuery('.job_listings').triggerHandler('update_results', [1, false]);
    });

    var APUS_Tab_Scroll = function(){
        "use strict";
        // perfect scroll
        $('.header-tabs-wrapper').each(function(){
            var total_wd = 0;
            $('.nav li', $(this)).each(function(){
                total_wd = total_wd + $(this).outerWidth();
            });
            $('.nav', $(this)).width(total_wd + 30);
            $('.header-tabs-nav', $(this)).width('100%');
        });
    }
    APUS_Tab_Scroll();

    $('.header-tabs-wrapper .header-tabs-nav').perfectScrollbar();
    $(window).resize(function(event) {
        APUS_Tab_Scroll();
        $('.header-tabs-wrapper .header-tabs-nav').perfectScrollbar('update');
    });
});

function setCookie(cname, cvalue, exdays) {
    var d = new Date();
    d.setTime(d.getTime() + (exdays*24*60*60*1000));
    var expires = "expires="+d.toUTCString();
    document.cookie = cname + "=" + cvalue + "; " + expires+";path=/";
}

function getCookie(cname) {
    var name = cname + "=";
    var ca = document.cookie.split(';');
    for(var i=0; i<ca.length; i++) {
        var c = ca[i];
        while (c.charAt(0)==' ') c = c.substring(1);
        if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
    }
    return "";
}
if (typeof google === 'object' && typeof google.maps === 'object') {
    function search_location_initialize() {
            
        var input = document.getElementById('search_location');
        var autocomplete = new google.maps.places.Autocomplete(input);
        autocomplete.setTypes([]);

        autocomplete.addListener( 'place_changed', function () {
            var place = autocomplete.getPlace();
            place.toString();
            console.log(place);
            if (!place.geometry) {
                window.alert("No details available for input: '" + place.name + "'");
                return;
            }
            document.getElementById('search_lat').value = place.geometry.location.lat();
            document.getElementById('search_lng').value = place.geometry.location.lng();
            jQuery('.job_listings').triggerHandler('update_results', [1, false]);
        });
    }
    google.maps.event.addDomListener(window, 'load', search_location_initialize);
}
jQuery(document).ready(function($){
    // geolocation
    function getLocation(position) {
        $('#search_lat').val(position.coords.latitude);
        $('#search_lng').val(position.coords.longitude);
        $('#search_location').val('Location');

        var geocoder = new google.maps.Geocoder();
        var latLng = new google.maps.LatLng(position.coords.latitude, position.coords.longitude);

        if (geocoder) {
            geocoder.geocode({ 'latLng': latLng}, function (results, status) {
                if (status == google.maps.GeocoderStatus.OK) {
                    $('#search_location').val(results[0].formatted_address);
                }
            });
        }
        setTimeout(function(){
            $('.job_listings').triggerHandler('update_results', [1, false]);
        }, 50);
        return $('.find-me').removeClass('loading');
    }
    function getErrorLocation(position) {
        return $('.find-me').removeClass('loading');
    }
    $('body').on('click', '.find-me', function() {
        $(this).addClass('loading');
        navigator.geolocation.getCurrentPosition(getLocation, getErrorLocation);
    });

    // gmap 3
    $('.apus-google-map').each(function(){
        var lat = $(this).data('lat');
        var lng = $(this).data('lng');
        var zoom = $(this).data('zoom');
        var id = $(this).attr('id');
        
        $('#'+id).gmap3({
            map:{
                options:{
                    "draggable": true
                    ,"mapTypeControl": true
                    ,"mapTypeId": google.maps.MapTypeId.ROADMAP
                    ,"scrollwheel": false
                    ,"panControl": true
                    ,"rotateControl": false
                    ,"scaleControl": true
                    ,"streetViewControl": true
                    ,"zoomControl": true
                    ,"center":[lat, lng]
                    ,"zoom": zoom
                    ,'styles': [
                        {
                            featureType: "all",
                            elementType: "all",
                            "stylers": [
                                {
                                    "featureType": "landscape.man_made",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "color": "#f7f1df"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "landscape.natural",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "color": "#d0e3b4"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "landscape.natural.terrain",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "visibility": "off"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "poi",
                                    "elementType": "labels",
                                    "stylers": [
                                        {
                                            "visibility": "off"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "poi.business",
                                    "elementType": "all",
                                    "stylers": [
                                        {
                                            "visibility": "off"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "poi.medical",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "color": "#fbd3da"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "poi.park",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "color": "#bde6ab"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road",
                                    "elementType": "geometry.stroke",
                                    "stylers": [
                                        {
                                            "visibility": "off"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road",
                                    "elementType": "labels",
                                    "stylers": [
                                        {
                                            "visibility": "off"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road.highway",
                                    "elementType": "geometry.fill",
                                    "stylers": [
                                        {
                                            "color": "#ffe15f"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road.highway",
                                    "elementType": "geometry.stroke",
                                    "stylers": [
                                        {
                                            "color": "#efd151"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road.arterial",
                                    "elementType": "geometry.fill",
                                    "stylers": [
                                        {
                                            "color": "#ffffff"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "road.local",
                                    "elementType": "geometry.fill",
                                    "stylers": [
                                        {
                                            "color": "black"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "transit.station.airport",
                                    "elementType": "geometry.fill",
                                    "stylers": [
                                        {
                                            "color": "#cfb2db"
                                        }
                                    ]
                                },
                                {
                                    "featureType": "water",
                                    "elementType": "geometry",
                                    "stylers": [
                                        {
                                            "color": "#a2daf2"
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            },
            marker:{
              latLng: [lat, lng]
            }
        });
    });
    
});
jQuery(function() {
    jQuery('[href="#down"]').on('click', function(e) {
        e.preventDefault();
        jQuery('html, body').animate({ scrollTop: jQuery(jQuery(this).attr('href')).offset().top}, 500, 'linear');
    });
});