(function($) {
    'use strict';
	if ($('#apus-listing-map').length) {
        L.Icon.Default.imagePath = 'wp-content/themes/apuslisting/assets/images/';
    }

    // Maps
    var ApusMap = (function() {

        function initProductImageLoad() {
            $(window).off('scroll.unveil resize.unveil lookup.unveil');
            var $images = $('.image-wrapper:not(.image-loaded) .unveil-image'); // Get un-loaded images only
            if ($images.length) {
                var scrollTolerance = 1;
                $images.unveil(scrollTolerance, function() {
                    $(this).load(function() {
                        $(this).parents('.image-wrapper').first().addClass('image-loaded');
                    });
                });
            }
        }

        var map, markers, CustomHtmlIcon;

        function initStreetView() {
            var panorama = null;
            
            $('.top-nav-street-view').click(function(e){
                e.preventDefault();
                $('#apus-listing-map-street-view').show();
                $('#apus-listing-map').hide();
                $('.top-nav-street-view').removeClass('active').addClass('active');
                $('.top-nav-map').removeClass('active');

                var $item = $('.apus-single-listing');

                if (typeof $item.data('latitude') !== "undefined" && $item.data('latitude') !== "" && typeof $item.data('longitude') !== "undefined" && $item.data('longitude') !== "") {
                    var zoom = (typeof MapWidgetZoom !== "undefined") ? MapWidgetZoom : 15;
                    
                    if ( panorama == null ) {
                        var fenway = new google.maps.LatLng($item.data('latitude'),$item.data('longitude'));
                        var panoramaOptions = {
                            position: fenway,
                            pov: {
                                heading: 34,
                                pitch: 10
                            }
                        };
                        panorama = new  google.maps.StreetViewPanorama(document.getElementById('apus-listing-map-street-view'),panoramaOptions);
                    }
                }
            });
        }

        function init() {
            initStreetView();

            var $window = $(window);
            if ($('.no_job_listings_found').length) {
                $('<div class="results">' + listing_params.strings['no_job_listings_found'] + '</div>').prependTo('.showing_jobs, .listing-search-result');
            }

            if (!$('#apus-listing-map').length) {
                $('.job_listings').on('updated_results', function(e, result) {
                    initProductImageLoad();
                    updateMakerCards(result.total_found, result);
                    $('[data-toggle="tooltip"]').tooltip(); 
                });
                return;
            }

            map = L.map('apus-listing-map', {
                scrollWheelZoom: false
            });

            markers = new L.MarkerClusterGroup({
                showCoverageOnHover: false
            });

            CustomHtmlIcon = L.HtmlIcon.extend({
                options: {
                    html: "<div class='map-popup'></div>",
                    iconSize: [48, 59],
                    iconAnchor: [24, 59],
                    popupAnchor: [0, -59]
                }
            });

            $window.on('pxg:refreshmap', function() {
                map._onResize();
                setTimeout(function() {
                    map.fitBounds(markers, {
                        padding: [50, 50]
                    });
                }, 100);
            });

            $window.on('pxg:simplerefreshmap', function() {
                map._onResize();
            });

            if ( listing_params.mapbox_token != '' ) {
                var tileLayer = L.tileLayer('https://api.tiles.mapbox.com/v4/' + listing_params.mapbox_style + '/{z}/{x}/{y}.png?access_token=' + listing_params.mapbox_token, {
                    maxZoom: 18,
                    attribution: '&copy; <a href="http://mapbox.com">Mapbox</a> | &copy; <a href="http://openstreetmap.org">OpenStreetMap</a>',
                    id: 'mapbox.streets'
                })
            } else {
                if ( listing_params.custom_style != '' ) {
                    try {
                       var custom_style = $.parseJSON(listing_params.custom_style);
                       var tileLayer = new L.Google('ROADMAP', {}, custom_style );
                    } catch(err) {
                        var tileLayer = new L.Google('ROADMAP');
                    }
                } else {
                    var tileLayer = new L.Google('ROADMAP');
                }
                $('#apus-listing-map').addClass('map--google');
            }

            map.addLayer(tileLayer);

            // check home/archive/single page
            if ( $('#apus-listing-map').is('.apus-homepage-listing-map') ) {
                updateMakerCards();
            } else {
                if ( !$('#apus-listing-map').is('.apus-single-listing-map') ) {

                    $('.job_listings').on('updated_results', function(e, result) {
                        initProductImageLoad();
                        updateMakerCards(result.total_found, result);
                        $('[data-toggle="tooltip"]').tooltip(); 
                    });
                    // FacetWP
                    $(document).on('facetwp-loaded', function(e, result) {
                        updateMakerCards();
                    });
                } else {
                    var $item = $('.apus-single-listing');
                    if (typeof $item.data('latitude') !== "undefined" && $item.data('latitude') !== "" && typeof $item.data('longitude') !== "undefined" && $item.data('longitude') !== "") {
                        var zoom = (typeof MapWidgetZoom !== "undefined") ? MapWidgetZoom : 15;
                        addMakerToMap($item);
                        map.addLayer(markers);
                        map.setActiveArea('active-area');
                        map.setView([$item.data('latitude'), $item.data('longitude')], zoom);
                        $(window).on('update:map', function() {
                            map.setView([$item.data('latitude'), $item.data('longitude')], zoom);
                        });
                        $('.top-nav-map').click(function(e){
                            e.preventDefault();
                            $('#apus-listing-map-street-view').hide();
                            $('#apus-listing-map').show();
                            $('.top-nav-street-view').removeClass('active');
                            $('.top-nav-map').removeClass('active').addClass('active');
                            map._onResize();
                        });
                    } else {
                        $('#apus-listing-map').hide();
                        $('.listing-address').css('marginTop', 0);
                    }
                }
            }
        }

        function updateMakerCards($total_found, $result) {
            var $items = $('.job_listings_cards .job_listing');
            
            $('.showing_jobs .results, .listing-search-result .results, .listing-search-result-filter .results').remove();

            $('<div class="results"><span class="results-no">' +
                    $items.length + '</span> ' + listing_params.strings['results-no'] +
                    '</div>').prependTo('.showing_jobs, .listing-search-result');

            if (typeof $result !== 'undefined' && $result.showing !== '' && $result.showing_links !== '') {
                $('<div class="results">' +
                    $result.showing + ' ' +
                    $result.showing_links +
                    '</div>').prependTo('.listing-search-result-filter');
            }
            if (!$items.length) {
                return;
            }

            if ($('#apus-listing-map').length && typeof map !== "undefined") {
                map.removeLayer(markers);
                markers = new L.MarkerClusterGroup({
                    showCoverageOnHover: false
                });
                $items.each(function(i, obj) {
                    addMakerToMap($(obj), true);
                });
                map.fitBounds(markers, {
                    padding: [50, 50]
                });

                map.addLayer(markers);
            }
        }

        function addMakerToMap($item, archive) {
            var category = $item.find('.listing-cat-icon'), mapPinClass, map;

            if ( $item.data('latitude') == "" || $item.data('longitude') == "") {
                return;
            }

            if ( !category.length ) {
                mapPinClass = 'map-popup map-popup-empty';
            } else {
                mapPinClass = 'map-popup';
            }
            var $mapPinIcon = $('.map-pin-icon');
            var mapPinHTML = "<div class='" + mapPinClass + "'>" + $mapPinIcon.html() + "<div class='icon-wrapper'><div class='icon-cat'>!</div></div></div>";

            if (category.length) {
                mapPinHTML = "<div class='" + mapPinClass + "'>" + $mapPinIcon.html() + "<div class='icon-cat'>" + category.html() + "</div></div>";
            }

            map = L.marker([$item.data('latitude'), $item.data('longitude')], {
                icon: new CustomHtmlIcon({ html: mapPinHTML })
            });

            if (typeof archive !== "undefined") {

                $item.hover(function() {
                    $(map._icon).find('.map-popup').addClass('map-popup-selected');
                }, function() {
                    $(map._icon).find('.map-popup').removeClass('map-popup-selected');
                });

                map.bindPopup(
                    "<div class='job-grid-style job_listing'>" +
                        "<div class='listing-image'>" +
                            "<div class='image-wrapper image-loaded'>" +
                                "<a class='map-popup-url' href='" + $item.data('permalink') + "'>" +
                                "<img src='" + $item.data('img') + "' alt=''>" +
                                "</a>" +
                            "</div>" +
                            "<div class='listing-time'>" + $item.find('.listing-time').html() + "</div>" +
                            "<div class='listing-title-wrapper'>"+
                                "<h3 class='listing-title'>" +
                                    $item.find('.listing-title').html() +
                                "</h3>" +
                                "<div class='listing-address'>" + $item.find('.listing-address').html() + "</div>" +
                            "</div>"+
                        "</div>" +
                        "<div class='listing-content clearfix'>" +
                            "<div class='listing-review pull-left'>" + $item.find('.listing-review').html() + "</div>" +
                            "<div class='listing-favorite pull-right'>" + $item.find('.listing-favorite').html() + "</div>" +
                        "</div>" +
                    "</div>").openPopup();
            }

            markers.addLayer(map);
        }

        return {
            init: init,
            updateResults: updateMakerCards
        }

    })();
    setTimeout(function() {
        ApusMap.init();    
    }, 100);
    
    jQuery(document).ready(function($){
        if ( $( 'div.job_listings' ).length > 0 ) {
            $( 'div.job_listings' ).triggerHandler( 'update_results', [ 1, false ] );
        }
    });
})(jQuery)