<?php
/**
 * favorite
 *
 * @package    apus-apuslisting
 * @author     ApusTheme <apusthemes@gmail.com >
 * @license    GNU General Public License, version 3
 * @copyright  13/06/2016 ApusTheme
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
 
class ApusApusListing_Favorite {
	
	public static function init() {
		add_action( 'wp_ajax_apuslisting_add_favorite', array(__CLASS__, 'add_favorite') );
		add_action( 'wp_ajax_nopriv_apuslisting_add_favorite', array(__CLASS__, 'add_favorite') );
		add_action( 'wp_ajax_apuslisting_remove_favorite', array(__CLASS__, 'remove_favorite') );
		add_action( 'wp_ajax_nopriv_apuslisting_remove_favorite', array(__CLASS__, 'remove_favorite') );

		add_action( 'wp_footer', array(__CLASS__, 'login_info') );

		add_filter( 'job_manager_settings', array(__CLASS__, 'settings'), 10, 1 );
		// shortcode
		add_shortcode( 'apus_listing_favorite' , array(__CLASS__, 'list_favorite') );
	}

	public static function add_favorite() {
		if ( isset($_GET['post_id']) && $_GET['post_id'] ) {
			self::save_wislist($_GET['post_id']);
			$result['msg'] = ApusApusListing_Template_Loader::get_template_part( 'favorite/result', array('status' => 'success') );
			$result['icon'] = ApusApusListing_Template_Loader::get_template_part( 'favorite/button-detail', array('post_id' => $_GET['post_id']) );
		} else {
			$result['msg'] = ApusApusListing_Template_Loader::get_template_part( 'favorite/result', array('status' => 'error') );
			$result['icon'] = '';
		}
		echo json_encode($result);
		die();
	}

	public static function remove_favorite() {
		if ( isset($_GET['post_id']) && $_GET['post_id'] ) {
			$user_id = get_current_user_id();
			$data = get_user_meta($user_id, '_favorite', true);
			if (is_array($data)) {
				foreach ($data as $key => $value) {
					if ( $_GET['post_id'] == $value ) {
						unset($data[$key]);
					}
				}
			}
			update_user_meta( $user_id, '_favorite', $data );
			// count favorite
			$counts = intval( get_post_meta($post_id, '_favorite_count', true) );
		    if( $counts != '' ) {
		        $counts--;
		    } else {
		        $counts = 0;
		    }
		    update_post_meta( $post_id, '_favorite_count', $counts );

			$result['msg'] = esc_html__( 'Remove a listing to favorite successful', 'apus-apuslisting' );
			$result['status'] = 1;
		} else {
			$result['msg'] = esc_html__( 'Remove a listing to favorite error', 'apus-apuslisting' );
			$result['status'] = 0;
		}
		echo json_encode($result);
		die();
	}

	public static function get_favorite() {
		$user_id = get_current_user_id();
		$data = get_user_meta($user_id, '_favorite', true);
		return $data;
	}

	public static function save_wislist($post_id) {
		$user_id = get_current_user_id();
		$data = get_user_meta($user_id, '_favorite', true);
		if ( !in_array($post_id, $data) ) {
			$data[] = $post_id;
			update_user_meta( $user_id, '_favorite', $data );
			// count favorite
			$counts = intval( get_post_meta($post_id, '_favorite_count', true) );
		    if( $counts != '' ) {
		        $counts++;
		    } else {
		        $counts = 1;
		    }
		    update_post_meta( $post_id, '_favorite_count', $counts );
		}
	}

	public static function check_listing_added($post_id) {
		$data = self::get_favorite();
		if ( !is_array($data) || !in_array($post_id, $data) ) {
			return false;
		}
		return true;
	}

	public static function login_info() {
		echo ApusApusListing_Template_Loader::get_template_part( 'favorite/login-info' );
	}

	public static function get_favorite_page() {
		return get_option('job_manager_favorite_page_id');
	}

	public static function settings($args) {
		$args['job_pages'][1][] = array(
			'name' 		=> 'job_manager_favorite_page_id',
			'std' 		=> '',
			'label' 	=> esc_html__( 'Apus Favorite Listings Page', 'apus-apuslisting' ),
			'desc'		=> esc_html__( 'Select the page where you have placed the [apus_listing_favorite] shortcode. This lets the plugin know where the job listings page is located.', 'apus-apuslisting' ),
			'type'      => 'page'
		);
		return $args;
	}

	public static function list_favorite() {
		echo ApusApusListing_Template_Loader::get_template_part( 'favorite/list' );
	}

	public static function get_listings( $ids, $post_per_page = -1, $paged = 1 ) {
		if ( empty($ids) || !is_array($ids) ) {
			return false;
		}
		$args = array(
			'post_type' => 'job_listing',
			'posts_per_page' => $post_per_page,
			'ignore_sticky_posts' => true,
			'paged' => $paged,
			'post__in' => $ids
		);

		$wp_query = new WP_Query( $args );
		return $wp_query;
	}
}

ApusApusListing_Favorite::init();