<?php

if ( !function_exists('apuslisting_get_products') ) {
    function apuslisting_get_products($product_type = 'recent_product', $paged = 1, $post_per_page = -1, $orderby = '', $order = '') {
        global $woocommerce, $wp_query;
        $args = array(
            'post_type' => 'product',
            'posts_per_page' => $post_per_page,
            'post_status' => 'publish',
            'paged' => $paged,
            'orderby'   => $orderby,
            'order' => $order
        );

        if ( isset( $args['orderby'] ) ) {
            if ( 'price' == $args['orderby'] ) {
                $args = array_merge( $args, array(
                    'meta_key'  => '_price',
                    'orderby'   => 'meta_value_num'
                ) );
            }
            if ( 'featured' == $args['orderby'] ) {
                $args = array_merge( $args, array(
                    'meta_key'  => '_featured',
                    'orderby'   => 'meta_value'
                ) );
            }
            if ( 'sku' == $args['orderby'] ) {
                $args = array_merge( $args, array(
                    'meta_key'  => '_sku',
                    'orderby'   => 'meta_value'
                ) );
            }
        }
        if ($product_type == 'recent_product') {
            $args['meta_query'] = array();
            $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
            $args['meta_query'][] = array(
               'key' => '_ywsbs_subscription',
               'value' => 'yes',
               'compare' => '=',
            );
        } 
        if ($product_type == 'job_package') {
            $args['tax_query'][] = array(
                'taxonomy' => 'product_type',
                'field'    => 'slug',
                'terms'    => array( 'job_package', 'job_package_subscription' )
            );
        } else {
            $args['orderby'] = 'date';
            $args['order'] = 'ASC';
        }
        
        return new WP_Query($args);
    }
}

function apuslisting_woocommerce_setup() {
    global $pagenow;
    if ( is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php' ) {
        $catalog = array(
            'width'     => '500',   // px
            'height'    => '500',   // px
            'crop'      => 1        // true
        );

        $single = array(
            'width'     => '1200',   // px
            'height'    => '1200',   // px
            'crop'      => 1        // true
        );

        $thumbnail = array(
            'width'     => '170',    // px
            'height'    => '170',   // px
            'crop'      => 1        // true
        );

        // Image sizes
        update_option( 'shop_catalog_image_size', $catalog );       // Product category thumbs
        update_option( 'shop_single_image_size', $single );         // Single product image
        update_option( 'shop_thumbnail_image_size', $thumbnail );   // Image gallery thumbs
    }

    if ( apuslisting_get_config('show_quickview') ) {
        add_action( 'wp_ajax_apuslisting_quickview_product', 'apuslisting_woocommerce_quickview' );
        add_action( 'wp_ajax_nopriv_apuslisting_quickview_product', 'apuslisting_woocommerce_quickview' );
    }
}

add_action( 'init', 'apuslisting_woocommerce_setup');


// cart modal
if ( !function_exists('apuslisting_woocommerce_cart_modal') ) {
    function apuslisting_woocommerce_cart_modal() {
        wc_get_template( 'content-product-cart-modal.php' , array( 'current_product_id' => (int)$_GET['product_id'] ) );
        die;
    }
}

add_action( 'wp_ajax_apuslisting_add_to_cart_product', 'apuslisting_woocommerce_cart_modal' );
add_action( 'wp_ajax_nopriv_apuslisting_add_to_cart_product', 'apuslisting_woocommerce_cart_modal' );


// hooks
if ( !function_exists('apuslisting_woocommerce_enqueue_styles') ) {
    function apuslisting_woocommerce_enqueue_styles() {
        wp_enqueue_style( 'apuslisting-woocommerce', get_template_directory_uri() .'/assets/css/woocommerce.css' , 'apuslisting-woocommerce-front' , APUSLISTING_THEME_VERSION, 'all' );
        wp_enqueue_script( 'apuslisting-woocommerce-script', get_template_directory_uri() . '/assets/js/woocommerce.js', array( 'jquery' ), '20150330', true );
        wp_enqueue_script( 'wc-add-to-cart-variation' );
        if ( is_singular('product') ) {
            // photoswipe
            wp_enqueue_script( 'photoswipe-js', get_template_directory_uri() . '/assets/js/photoswipe/photoswipe.min.js', array( 'jquery' ), '20150315', true );
            wp_enqueue_script( 'photoswipe-ui-js', get_template_directory_uri() . '/assets/js/photoswipe/photoswipe-ui-default.min.js', array( 'jquery' ), '20150315', true );
            wp_enqueue_script( 'photoswipe-init', get_template_directory_uri() . '/assets/js/photoswipe/photoswipe.init.js', array( 'jquery' ), '20150315', true );
            wp_enqueue_style( 'photoswipe-style', get_template_directory_uri() . '/assets/js/photoswipe/photoswipe.css', array(), '3.2.0' );
            wp_enqueue_style( 'photoswipe-skin-style', get_template_directory_uri() . '/assets/js/photoswipe/default-skin/default-skin.css', array(), '3.2.0' );

        }
    }
}
add_action( 'wp_enqueue_scripts', 'apuslisting_woocommerce_enqueue_styles', 150 );

// cart
if ( !function_exists('apuslisting_woocommerce_header_add_to_cart_fragment') ) {
    function apuslisting_woocommerce_header_add_to_cart_fragment( $fragments ){
        global $woocommerce;
        $fragments['#cart .count'] =  sprintf(_n(' <span class="count"> %d  </span> ', ' <span class="count"> %d </span> ', $woocommerce->cart->cart_contents_count, 'apuslisting'), $woocommerce->cart->cart_contents_count);
        $fragments['#cart .mini-cart-total'] = trim( $woocommerce->cart->get_cart_total() );
        return $fragments;
    }
}
add_filter('woocommerce_add_to_cart_fragments', 'apuslisting_woocommerce_header_add_to_cart_fragment' );

// breadcrumb for woocommerce page
if ( !function_exists('apuslisting_woocommerce_breadcrumb_defaults') ) {
    function apuslisting_woocommerce_breadcrumb_defaults( $args ) {
        $breadcrumb_img = apuslisting_get_config('woo_breadcrumb_image');
        $breadcrumb_color = apuslisting_get_config('woo_breadcrumb_color');
        $style = array();
        $show_breadcrumbs = apuslisting_get_config('show_product_breadcrumbs');
        $has_img = '';
        if ( !$show_breadcrumbs ) {
            $style[] = 'display:none';
        }
        if( $breadcrumb_color  ){
            $style[] = 'background-color:'.$breadcrumb_color;
        }
        if ( isset($breadcrumb_img['url']) && !empty($breadcrumb_img['url']) ) {
            $style[] = 'background-image:url(\''.esc_url($breadcrumb_img['url']).'\')';
            $has_img = 1;
        }
        $estyle = !empty($style)? ' style="'.implode(";", $style).'"':"";
        if($has_img) $has_img = 'has-img';
        if ( is_single() ) {
            $title = esc_html__('Product Detail', 'apuslisting');
        } else {
            $title = esc_html__('Products List', 'apuslisting');
        }
        $args['wrap_before'] = '<section id="apus-breadscrumb" class="apus-breadscrumb '.$has_img.'"'.$estyle.'><div class="container"><div class="wrapper-breads"><div class="breadscrumb-inner"><ol class="apus-woocommerce-breadcrumb breadcrumb" ' . ( is_single() ? 'itemprop="breadcrumb"' : '' ) . '>';
        $args['wrap_after'] = '</ol><h2 class="bread-title">'.$title.'</h2></div></div></div></section>';

        return $args;
    }
}
add_filter( 'woocommerce_breadcrumb_defaults', 'apuslisting_woocommerce_breadcrumb_defaults' );
add_action( 'apuslisting_woo_template_main_before', 'woocommerce_breadcrumb', 30, 0 );

// display woocommerce modes
if ( !function_exists('apuslisting_woocommerce_display_modes') ) {
    function apuslisting_woocommerce_display_modes(){
        global $wp;
        $current_url = apuslisting_shop_page_link(true);

        $url_grid = add_query_arg( 'display_mode', 'grid', remove_query_arg( 'display_mode', $current_url ) );
        $url_list = add_query_arg( 'display_mode', 'list', remove_query_arg( 'display_mode', $current_url ) );

        $woo_mode = apuslisting_woocommerce_get_display_mode();

        echo '<div class="display-mode">';
        echo '<a href="'.  $url_grid  .'" class=" change-view '.($woo_mode == 'grid' ? 'active' : '').'"><i class="fa fa-th"></i>'.esc_html__('Grid','apuslisting').'</a>';
        echo '<a href="'.  $url_list  .'" class=" change-view '.($woo_mode == 'list' ? 'active' : '').'"><i class="fa fa-th-list"></i>'.esc_html__('List','apuslisting').'</a>';
        echo '</div>'; 
    }
}
add_action( 'woocommerce_before_shop_loop', 'apuslisting_woocommerce_display_modes' , 2 );

if ( !function_exists('apuslisting_woocommerce_get_display_mode') ) {
    function apuslisting_woocommerce_get_display_mode() {
        $woo_mode = apuslisting_get_config('product_display_mode', 'grid');
        if ( isset($_COOKIE['apuslisting_woo_mode']) && ($_COOKIE['apuslisting_woo_mode'] == 'list' || $_COOKIE['apuslisting_woo_mode'] == 'grid') ) {
            $woo_mode = $_COOKIE['apuslisting_woo_mode'];
        }
        return $woo_mode;
    }
}

if(!function_exists('apuslisting_shop_page_link')) {
    function apuslisting_shop_page_link($keep_query = false ) {
        if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
            $link = home_url();
        } elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id('shop') ) ) {
            $link = get_post_type_archive_link( 'product' );
        } else {
            $link = get_term_link( get_query_var('term'), get_query_var('taxonomy') );
        }

        if( $keep_query ) {
            // Keep query string vars intact
            foreach ( $_GET as $key => $val ) {
                if ( 'orderby' === $key || 'submit' === $key ) {
                    continue;
                }
                $link = add_query_arg( $key, $val, $link );

            }
        }
        return $link;
    }
}


if(!function_exists('apuslisting_filter_before')){
    function apuslisting_filter_before(){
        echo '<div class="apus-filter">';
    }
}
if(!function_exists('apuslisting_filter_after')){
    function apuslisting_filter_after(){
        echo '</div>';
    }
}
add_action( 'woocommerce_before_shop_loop', 'apuslisting_filter_before' , 1 );
add_action( 'woocommerce_before_shop_loop', 'apuslisting_filter_after' , 40 );

// set display mode to cookie
if ( !function_exists('apuslisting_before_woocommerce_init') ) {
    function apuslisting_before_woocommerce_init() {
        if( isset($_GET['display_mode']) && ($_GET['display_mode']=='list' || $_GET['display_mode']=='grid') ){  
            setcookie( 'apuslisting_woo_mode', trim($_GET['display_mode']) , time()+3600*24*100,'/' );
            $_COOKIE['apuslisting_woo_mode'] = trim($_GET['display_mode']);
        }
    }
}
add_action( 'init', 'apuslisting_before_woocommerce_init' );

// Number of products per page
if ( !function_exists('apuslisting_woocommerce_shop_per_page') ) {
    function apuslisting_woocommerce_shop_per_page($number) {
        $value = apuslisting_get_config('number_products_per_page');
        if ( is_numeric( $value ) && $value ) {
            $number = absint( $value );
        }
        return $number;
    }
}
add_filter( 'loop_shop_per_page', 'apuslisting_woocommerce_shop_per_page' );

// Number of products per row
if ( !function_exists('apuslisting_woocommerce_shop_columns') ) {
    function apuslisting_woocommerce_shop_columns($number) {
        $value = apuslisting_get_config('product_columns');
        if ( in_array( $value, array(2, 3, 4, 6) ) ) {
            $number = $value;
        }
        return $number;
    }
}
add_filter( 'loop_shop_columns', 'apuslisting_woocommerce_shop_columns' );

// share box
if ( !function_exists('apuslisting_woocommerce_share_box') ) {
    function apuslisting_woocommerce_share_box() {
        if ( apuslisting_get_config('show_product_social_share') ) {
            get_template_part( 'page-templates/parts/sharebox' );
        }
    }
}
add_filter( 'woocommerce_single_product_summary', 'apuslisting_woocommerce_share_box', 100 );


// quickview
if ( !function_exists('apuslisting_woocommerce_quickview') ) {
    function apuslisting_woocommerce_quickview() {
        $args = array(
            'post_type'=>'product',
            'product' => $_GET['productslug']
        );
        $query = new WP_Query($args);
        if ( $query->have_posts() ) {
            while ($query->have_posts()): $query->the_post(); global $product;
                wc_get_template_part( 'content', 'product-quickview' );
            endwhile;
        }
        wp_reset_postdata();
        die;
    }
}

// swap effect
if ( !function_exists('apuslisting_swap_images') ) {
    function apuslisting_swap_images() {
        global $post, $product, $woocommerce;
        
        $output = '';
        $class = 'image-no-effect unveil-image';
        if (has_post_thumbnail()) {
            if ( apuslisting_get_config('show_image_style') == 'swap' ) {
                $attachment_ids = $product->get_gallery_image_ids();
                if ($attachment_ids && isset($attachment_ids[0])) {
                    $class = 'image-hover';
                    $product_thumbnail_title = get_the_title( $attachment_ids[0] );
                    $product_thumbnail = wp_get_attachment_image_src( $attachment_ids[0], 'shop_catalog' );
                    $placeholder_image = apuslisting_create_placeholder(array($product_thumbnail[1],$product_thumbnail[2]));
                    if ( apuslisting_get_config('image_lazy_loading') ) {
                        echo '<img src="' . $placeholder_image . '" data-src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-shop-catalog unveil-image image-effect" />';
                    } else {
                        echo '<img src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-shop-catalog image-effect" />';
                    }
                }
            }
            $product_thumbnail_id = get_post_thumbnail_id();
            $product_thumbnail_title = get_the_title( $product_thumbnail_id );
            $product_thumbnail = wp_get_attachment_image_src( $product_thumbnail_id, 'shop_catalog' );
            $placeholder_image = apuslisting_create_placeholder(array($product_thumbnail[1],$product_thumbnail[2]));

            if ( apuslisting_get_config('image_lazy_loading') ) {
                echo '<img src="' . $placeholder_image . '" data-src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-shop-catalog unveil-image '.esc_attr($class).'" />';
            } else {
                echo '<img src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-shop-catalog '.esc_attr($class).'" />';
            }
        } else {
            $image_sizes = get_option('shop_catalog_image_size');
            $placeholder_width = $image_sizes['width'];
            $placeholder_height = $image_sizes['height'];

            $output .= '<img src="'.wc_placeholder_img_src().'" alt="'.esc_html__('Placeholder' , 'apuslisting').'" class="'.$class.'" width="'.$placeholder_width.'" height="'.$placeholder_height.'" />';
        }
        echo trim($output);
    }
}
remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
add_action('woocommerce_before_shop_loop_item_title', 'apuslisting_swap_images', 10);

// get image
if ( !function_exists('apuslisting_product_get_image') ) {
    function apuslisting_product_get_image($thumb = 'shop_thumbnail') {
        global $product;
        $product_thumbnail_id = get_post_thumbnail_id();
        $product_thumbnail_title = get_the_title( $product_thumbnail_id );
        $product_thumbnail = wp_get_attachment_image_src( $product_thumbnail_id, $thumb );
        
        $placeholder_image = apuslisting_create_placeholder(array($product_thumbnail[1],$product_thumbnail[2]));

        if ( apuslisting_get_config('image_lazy_loading') ) {
            echo '<img src="' . $placeholder_image . '" data-src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-'.esc_attr($thumb).' size-'.esc_attr($thumb).' wp-post-image unveil-image" />';
        } else {
            echo '<img src="' . esc_url( $product_thumbnail[0] ) . '" width="' . esc_attr( $product_thumbnail[1] ) . '" height="' . esc_attr( $product_thumbnail[2] ) . '" alt="' . esc_attr( $product_thumbnail_title ) . '" class="attachment-'.esc_attr($thumb).' size-'.esc_attr($thumb).' wp-post-image" />';
        }
    }
}

// layout class for woo page
if ( !function_exists('apuslisting_woocommerce_content_class') ) {
    function apuslisting_woocommerce_content_class( $class ) {
        $page = 'archive';
        if ( is_singular( 'product' ) ) {
            $page = 'single';
        }
        if( apuslisting_get_config('product_'.$page.'_fullwidth') ) {
            return 'container-fluid';
        }
        return $class;
    }
}
add_filter( 'apuslisting_woocommerce_content_class', 'apuslisting_woocommerce_content_class' );

// get layout configs
if ( !function_exists('apuslisting_get_woocommerce_layout_configs') ) {
    function apuslisting_get_woocommerce_layout_configs() {
        $page = 'archive';
        if ( is_singular( 'product' ) ) {
            $page = 'single';
        }
        $left = apuslisting_get_config('product_'.$page.'_left_sidebar');
        $right = apuslisting_get_config('product_'.$page.'_right_sidebar');

        switch ( apuslisting_get_config('product_'.$page.'_layout') ) {
            case 'left-main':
                $configs['left'] = array( 'sidebar' => $left, 'class' => 'col-md-3 col-sm-12 col-xs-12'  );
                $configs['main'] = array( 'class' => 'col-md-9 col-sm-12 col-xs-12' );
                break;
            case 'main-right':
                $configs['right'] = array( 'sidebar' => $right,  'class' => 'col-md-3 col-sm-12 col-xs-12' ); 
                $configs['main'] = array( 'class' => 'col-md-9 col-sm-12 col-xs-12' );
                break;
            case 'main':
                $configs['main'] = array( 'class' => 'col-md-12 col-sm-12 col-xs-12' );
                break;
            case 'left-main-right':
                $configs['left'] = array( 'sidebar' => $left,  'class' => 'col-md-3 col-sm-12 col-xs-12'  );
                $configs['right'] = array( 'sidebar' => $right, 'class' => 'col-md-3 col-sm-12 col-xs-12' ); 
                $configs['main'] = array( 'class' => 'col-md-6 col-sm-12 col-xs-12' );
                break;
            default:
                $configs['main'] = array( 'class' => 'col-md-12 col-sm-12 col-xs-12' );
                break;
        }

        return $configs; 
    }
}

// Show/Hide related, upsells products
if ( !function_exists('apuslisting_woocommerce_related_upsells_products') ) {
    function apuslisting_woocommerce_related_upsells_products($located, $template_name) {
        $content_none = get_template_directory() . '/woocommerce/content-none.php';
        $show_product_releated = apuslisting_get_config('show_product_releated');
        if ( 'single-product/related.php' == $template_name ) {
            if ( !$show_product_releated  ) {
                $located = $content_none;
            }
        } elseif ( 'single-product/up-sells.php' == $template_name ) {
            $show_product_upsells = apuslisting_get_config('show_product_upsells');
            if ( !$show_product_upsells ) {
                $located = $content_none;
            }
        }

        return apply_filters( 'apuslisting_woocommerce_related_upsells_products', $located, $template_name );
    }
}
add_filter( 'wc_get_template', 'apuslisting_woocommerce_related_upsells_products', 10, 2 );

if ( !function_exists( 'apuslisting_product_review_tab' ) ) {
    function apuslisting_product_review_tab($tabs) {
        if ( !apuslisting_get_config('show_product_review_tab') && isset($tabs['reviews']) ) {
            unset( $tabs['reviews'] ); 
        }
        return $tabs;
    }
}
add_filter( 'woocommerce_product_tabs', 'apuslisting_product_review_tab', 100 );


// Favorite
add_filter( 'yith_wcwl_button_label', 'apuslisting_woocomerce_icon_favorite'  );
add_filter( 'yith-wcwl-browse-favorite-label', 'apuslisting_woocomerce_icon_favorite_add' );
function apuslisting_woocomerce_icon_favorite( $value='' ){
    return '<i class="icon-heart-outline"></i>'.'<span class="sub-title">'.esc_html__('Add to Favorite','apuslisting').'</span>';
}

function apuslisting_woocomerce_icon_favorite_add(){
    return '<i class="icon-down"></i>'.'<span class="sub-title">'.esc_html__('Favoriteed','apuslisting').'</span>';
}
remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );


function apuslisting_woocommerce_photoswipe() {
    if ( !is_singular('product') ) {
        return;
    }
    ?>
    <div class="pswp" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="pswp__bg"></div>

        <div class="pswp__scroll-wrap">

          <div class="pswp__container">
            <div class="pswp__item"></div>
            <div class="pswp__item"></div>
            <div class="pswp__item"></div>
          </div>

          <div class="pswp__ui pswp__ui--hidden">
            <div class="pswp__top-bar">
                <div class="pswp__counter"></div>
                <button class="pswp__button pswp__button--close" title="<?php echo esc_html__('Close (Esc)', 'apuslisting'); ?>"></button>
                <button class="pswp__button pswp__button--share" title="<?php echo esc_html__('Share', 'apuslisting'); ?>"></button>
                <button class="pswp__button pswp__button--fs" title="<?php echo esc_html__('Toggle fullscreen', 'apuslisting'); ?>"></button>
                <button class="pswp__button pswp__button--zoom" title="<?php echo esc_html__('Zoom in/out', 'apuslisting'); ?>"></button>
                <div class="pswp__preloader">
                    <div class="pswp__preloader__icn">
                      <div class="pswp__preloader__cut">
                        <div class="pswp__preloader__donut"></div>
                      </div>
                    </div>
                </div>
            </div>
            <div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
                <div class="pswp__share-tooltip"></div>
            </div>
            <button class="pswp__button pswp__button--arrow--left" title="<?php echo esc_html__('Previous (arrow left)', 'apuslisting'); ?>"></button>
            <button class="pswp__button pswp__button--arrow--right" title="<?php echo esc_html__('Next (arrow right)', 'apuslisting'); ?>"></button>
            <div class="pswp__caption">
              <div class="pswp__caption__center">
              </div>
            </div>
          </div>

        </div>
    </div>
    <?php
}
add_action( 'wp_footer', 'apuslisting_woocommerce_photoswipe' );

