<?php

if ( ! function_exists( 'apuslisting_get_term_icon_url' ) ) {
	function apuslisting_get_term_icon_url( $term_id = null ) {
		if ( class_exists('Taxonomy_MetaData_CMB2') ) {
			return Taxonomy_MetaData_CMB2::get( 'job_listing_category', $term_id, 'icon' );
		} else {
			return '';
		}
	}
}

if ( ! function_exists( 'apuslisting_get_post_image_src' ) ) {
	function apuslisting_get_post_image_src( $post_id = null, $size = 'thumbnail' ) {
		if ( empty( $post_id ) ) {
			$post_id = get_the_ID();
		}

		if ( has_post_thumbnail( $post_id ) ) {
			$attach_id = esc_sql( get_post_thumbnail_id( $post_id ) );
			$data = wp_get_attachment_image_src( $attach_id, $size );
			if ( isset( $data[0] ) && ! empty ( $data ) ) {
				return $data[0];
			}
		}
		$gallery_ids = apuslisting_get_listing_gallery( $post_id );
		if (!empty($gallery_ids) && isset($gallery_ids[0]) && $gallery_ids[0]) {
			return $gallery_ids[0];
		}

		return false;
	}
}

if ( ! function_exists( 'apuslisting_display_listing_image' ) ) {
	function apuslisting_display_listing_image( $size = 'thumbnail', $link = true, $post = null ) {
		if ( empty($post) ) {
			global $post;
		}
		$post_id = $post->ID;

		if ( has_post_thumbnail( $post_id ) ) {
			$attach_id = esc_sql( get_post_thumbnail_id( $post_id ) );
			$data = wp_get_attachment_image_src( $attach_id, $size );
			if ( isset( $data[0] ) && ! empty ( $data ) ) {
				$img = $data;
			}
		} else {
			$gallery_ids = apuslisting_get_listing_gallery( $post_id );
			if (!empty($gallery_ids) && isset($gallery_ids[0]) && $gallery_ids[0]) {
				$img = $gallery_ids;
			}
		}
		if (isset($img) && !empty($img)) {
			$img_src = $img[0];

			if (apuslisting_get_config('image_lazy_loading', true)) {
				$placeholder_image = apuslisting_create_placeholder(array($img[1],$img[2]));
				?>
				<div class="image-wrapper">
					<?php if ($link) { ?>
						<a href="<?php the_job_permalink($post); ?>">
					<?php } ?>
							<img src="<?php echo esc_attr($placeholder_image); ?>" data-src="<?php echo esc_url_raw($img_src); ?>" alt="" class="unveil-image">
					<?php if ($link) { ?>
						</a>
					<?php } ?>
				</div>
				<?php
			} else {
				?>
				<div class="image-wrapper">
					<?php if ($link) { ?>
						<a href="<?php the_job_permalink($post); ?>">
					<?php } ?>
							<img src="<?php echo esc_url($img_src); ?>" alt="<?php echo esc_attr( get_the_company_name( $post ) ); ?>">
					<?php if ($link) { ?>
						</a>
					<?php } ?>
				</div>
				<?php
			}
		}
	}
}

if ( ! function_exists( 'apuslisting_get_listing_gallery' ) ) {
	function apuslisting_get_listing_gallery( $post_id ) {
		$ids = array();
		if ( has_post_thumbnail($post_id) ) {
			$ids[get_post_thumbnail_id($post_id)] = get_post_thumbnail_id($post_id);
		}
		if ( defined('APUSAPUSLISTING_PREFIX') ) {
			$return  =  get_post_meta( $post_id, APUSAPUSLISTING_PREFIX . 'gallery_images', true );
			if ( !empty($return) ) {
				$ids = $ids + $return;
			}
		}
		return $ids;
	}
}

function apuslisting_sort_array_by_priority( $a, $b ) {
	if ( $a['priority'] == $b['priority'] ) {
		return 0;
	}

	return ( $a['priority'] < $b['priority'] ) ? - 1 : 1;
}

function apuslisting_check_submit() {
	if ( in_array( 'yith-woocommerce-subscription/init.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		if ( !is_user_logged_in() ) {
			return false;
		}
		$user_subscribes = apuslisting_get_subscribes_by_user();
		if (!$user_subscribes) {
			return false;
		}
		$sub = new YWSBS_Subscription($user_subscribes->ID);
		$metas = $sub->get_subscription_meta();

		if (empty($metas) || !isset($metas['status']) || $metas['status'] != 'active') {
			return false;
		}
		$start_date = isset($metas['start_date']) ? $metas['start_date'] : '';
		$expired_date = isset($metas['expired_date']) ? $metas['expired_date'] : '';

		$number_listings = (int)get_post_meta($user_subscribes->ID, '_number_listings', true);
		$current_number_listings = get_post_meta( $user_subscribes->ID, '_current_number_listings', true );
		if (is_array($current_number_listings)) {
			$current_number_listings = count($current_number_listings);
		} else {
			$current_number_listings = 0;
		}
		$now = current_time('timestamp');
		if ( $now >= $start_date && $now <= $expired_date && $current_number_listings < $number_listings ) {
			return true;
		}
		return false;
	}
	return true;
}

function apuslisting_get_subscribes_by_user(){
	$args = array(
	    'author' =>  get_current_user_id(), // I could also use $user_ID, right?
	    'orderby' =>  'post_date',
	    'order' =>  'DESC',
	    'posts_per_page' => 1,
	    'post_type' => 'ywsbs_subscription'
    );
    $subscribes = get_posts( $args );
    if (!empty($subscribes) && isset($subscribes[0])) {
    	return $subscribes[0];
    }
    return false;
}

function apuslisting_get_current_time() {
	global $wp_locale;
	$timezone  = get_option('gmt_offset');
	$time = gmdate(get_option('time_format'), time() + 3600*($timezone+date("I"))); 
	// $day =  gmdate("l");
	// setlocale(LC_ALL, get_locale().'.utf-8');
	// $day = strftime("%A");
	// $day = ucfirst($day);
	$time = strtotime($time);
	$day_of_week = date('N',$time);
	if ( $day_of_week == 7 ) {
		$day_of_week = 0;
	}
	$day = $wp_locale->get_weekday( $day_of_week );
	$day = ucfirst($day);
	return array( 'day' => $day, 'time' => $time );
}

function apuslisting_get_current_time_status($listing_id) {
	$current = apuslisting_get_current_time();
	$current_day = strtolower($current['day']);
	$current_time = $current['time'];
	$hours = get_post_meta( $listing_id, '_job_hours', true );
	$days = apuslisting_get_day_hours($hours);
	if ( !empty($days[$current_day]) ) {
		$times = $days[$current_day];
		if ( is_array($times) && count($times) == 2 ) {
			$opentime = strtotime($times[0]);	
			$closedtime = strtotime($times[1]);
			if ( $current_time >= $opentime && $current_time <= $closedtime ) {
				return true;
			}
		}
	}
	return false;
}

function apuslisting_create_attachment( $attachment_url, $post_id = 0 ) {
	include_once ABSPATH . 'wp-admin/includes/image.php';
	include_once ABSPATH . 'wp-admin/includes/media.php';

	$upload_dir     = wp_upload_dir();
	$attachment_url = esc_url( $attachment_url, array( 'http', 'https' ) );
	if ( empty( $attachment_url ) ) {
		return 0;
	}

	$attachment_url = str_replace( array( $upload_dir['baseurl'], WP_CONTENT_URL, site_url( '/' ) ), array( $upload_dir['basedir'], WP_CONTENT_DIR, ABSPATH ), $attachment_url );
	if ( empty( $attachment_url ) || ! is_string( $attachment_url ) ) {
		return 0;
	}

	$attachment = array(
		'post_title'   => esc_html__('Attachment Image', 'apuslisting'),
		'post_content' => '',
		'post_status'  => 'inherit',
		'post_parent'  => $post_id,
		'guid'         => $attachment_url,
	);

	$info = wp_check_filetype( $attachment_url );
	if ( $info ) {
		$attachment['post_mime_type'] = $info['type'];
	}

	$attachment_id = wp_insert_attachment( $attachment, $attachment_url, $post_id );

	if ( ! is_wp_error( $attachment_id ) ) {
		wp_update_attachment_metadata( $attachment_id, wp_generate_attachment_metadata( $attachment_id, $attachment_url ) );
		return $attachment_id;
	}

	return 0;
}