<?php

// get listings
function apuslisting_get_listings( $args = array() ) {
	$args = wp_parse_args( $args, array(
		'type' => '',
		'post_per_page' => -1,
		'paged' => 1,
		'categories' => '',
		'regions' => '',
	));

	$query_args = array(
		'post_type' => 'job_listing',
		'post_status' => 'publish',
		'posts_per_page' => $args['post_per_page'],
		'ignore_sticky_posts' => true,
		'paged' => $args['paged']
	);

	if ( $args['type'] == 'popular' ) {
		$query_args['meta_key'] = '_listing_views_count';
		$query_args['order'] = 'DESC';
	} elseif ( $args['type'] == 'featured' ) {
		$query_args['meta_query'] =  array(
	       	array(
	           'key' => '_featured',
	           'value' => '1',
	           'compare' => '=',
	       	)
		);
	}

	if ( !empty($args['categories']) && is_array($args['categories']) ) {
        $query_args['tax_query'][] = array(
            'taxonomy'      => 'job_listing_category',
            'field'         => 'slug',
            'terms'         => $args['categories'],
            'operator'      => 'IN'
        );
    }

    if ( !empty($args['regions']) && is_array($args['regions']) ) {
        $query_args['tax_query'][] = array(
            'taxonomy'      => 'job_listing_region',
            'field'         => 'slug',
            'terms'         => $args['regions'],
            'operator'      => 'IN'
        );
    }

	$wp_query = new WP_Query( $query_args );
	return $wp_query;
}

function apuslisting_get_listings_nearby($categories, $lat, $lng, $post_per_page = -1, $excludes = array()) {
	global $wpdb, $wp_query;
	$args = array(
		'post_type' => 'job_listing',
		'post_status' => 'publish',
		'posts_per_page' => $post_per_page,
		'ignore_sticky_posts' => true,
		'paged' => 1
	);
	if ($categories) {
		foreach ($categories as $category) {
			$tax_query[] = array(
				'taxonomy' => 'job_listing_category',
				'field'    => 'term_id',
				'terms'    => $category
			);
		}
		$args['tax_query'] = $tax_query;
	}
	if (!empty($excludes)) {
		$args['post__not_in'] = $excludes;
	}

	$use_distance = true;
	$distance = 50;
	$location = true;

	if ( !( $use_distance && $lat && $lng && $distance ) || !$location ) {
		return false;
	}
	$earth_distance = 3959;

	$sql = $wpdb->prepare( "
		SELECT $wpdb->posts.ID, 
			( %s * acos( 
				cos( radians(%s) ) * 
				cos( radians( latitude.meta_value ) ) * 
				cos( radians( longitude.meta_value ) - radians(%s) ) + 
				sin( radians(%s) ) * 
				sin( radians( latitude.meta_value ) ) 
			) ) 
			AS distance, latitude.meta_value AS latitude, longitude.meta_value AS longitude
			FROM $wpdb->posts
			INNER JOIN $wpdb->postmeta AS latitude ON $wpdb->posts.ID = latitude.post_id
			INNER JOIN $wpdb->postmeta AS longitude ON $wpdb->posts.ID = longitude.post_id
			WHERE 1=1 AND ($wpdb->posts.post_status = 'publish' ) AND latitude.meta_key='geolocation_lat' AND longitude.meta_key='geolocation_long' 
			HAVING distance < %s
			ORDER BY $wpdb->posts.menu_order ASC, distance ASC",
		$earth_distance,
		$lat,
		$lng,
		$lat,
		$distance
	);

	$post_ids = $wpdb->get_results( $sql, OBJECT_K );

	$distances = array();
	if ( empty( $post_ids ) || ! $post_ids ) {
        $post_ids = array(0);
	} else {
		foreach ($post_ids as $listing) {
			$distances[$listing->ID] = $listing->distance;
		}
		
	}
	$args[ 'post__in' ] = array_keys( (array) $post_ids );
	$args = apuslisting_remove_location_meta_query( $args );
	$listings = get_posts( $args );

	return array( 'listings' => $listings, 'distances' => $distances );
}

function apuslisting_set_post_views($postID) {
    $count_key = '_listing_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if ($count == '') {
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    } else {
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

function apuslisting_track_post_views ($post_id) {
    if ( !is_singular('job_listing') )
    	return;
    if ( empty ( $post_id) ) {
        global $post;
        $post_id = $post->ID;    
    }
    apuslisting_set_post_views($post_id);
}
add_action( 'wp_head', 'apuslisting_track_post_views');

if ( !function_exists('apuslisting_listing_content_class') ) {
	function apuslisting_listing_content_class( $class ) {
		$page = 'archive';
		if ( is_singular( 'job_listing' ) ) {
            $page = 'single';
        }
		if ( apuslisting_get_config('listing_'.$page.'_fullwidth') ) {
			return 'container-fluid';
		}
		return $class;
	}
}
add_filter( 'apuslisting_listing_content_class', 'apuslisting_listing_content_class', 1 , 1  );


if ( !function_exists('apuslisting_get_listings_sidebar_configs') ) {
	function apuslisting_get_listings_sidebar_configs() {
		$page = 'archive';
		if ( is_singular( 'job_listing' ) ) {
            $page = 'single';
        }
		$sidebar = apuslisting_get_config('listing_'.$page.'_sidebar');

		switch ( apuslisting_get_config('listing_'.$page.'_layout') ) {
			case 'main':
		 		$configs = array( 'sidebar' => $sidebar,  'class' => '' );
		 		break;
		 	case 'main-right':
		 		$configs = array( 'sidebar' => $sidebar,  'class' => 'pull-right' );
		 		break;
	 		case 'left-main':
		 	default:
		 		$configs = array( 'sidebar' => $sidebar, 'class' => 'pull-left' );
		 		break;
		}

		return $configs; 
	}
}

function apuslisting_get_listing_archive_version() {
	$version = apuslisting_get_config('listing_archive_layout_version', 'half-map');
	$version = !empty($version) ? $version : 'half-map';
	
	return $version;
}

function apuslisting_get_listing_item_style() {
	return apuslisting_get_listing_display_mode();
}

function apuslisting_get_listing_display_mode() {
	if (isset($_COOKIE['apuslisting_display_mode']) && in_array($_COOKIE['apuslisting_display_mode'], array('grid', 'list'))) {
		return $_COOKIE['apuslisting_display_mode'];
	}
	return apuslisting_get_config('listing_archive_display_mode', 'grid');
}

function apuslisting_get_listing_item_columns() {
	$display_mode = apuslisting_get_listing_display_mode();
	switch ($display_mode) {
		case 'list':
			$columns = 1;
			break;
		default:
			$columns = apuslisting_get_config('listing_columns', 2);
			break;
	}
	return apply_filters( 'apuslisting_get_listing_item_columns', $columns );
}

function apuslisting_get_listing_single_version() {
	$single_layout = apuslisting_get_config('listing_single_layout_version', 'v1');
	$single_layout = !empty($single_layout) ? $single_layout : 'v1';
	return $single_layout;
}

function apuslisting_listing_scripts() {
	global $post;
 	$post_type = get_query_var('post_type');
 	$load_script = false;
 	if (is_page() && is_object($post)) {
 		$job_page = get_option( 'job_manager_jobs_page_id' );
 		if (isset($post->ID) && $post->ID == $job_page) {
 			$load_script = true;
 		}
 	} elseif ( is_tax('job_listing_category') || is_tax('job_listing_tag') ||
		is_tax('job_listing_region') || is_tax('job_listing_type') || is_archive('job_listing') ||
		( is_search() && $post_type == 'job_listing' ) ) {
		$load_script = true;
	} elseif ( is_singular('job_listing') ) {
		$load_script = true;
	}
	if ($load_script) {
		apuslisting_listing_add_scripts();
	}
}
add_action( 'wp_enqueue_scripts', 'apuslisting_listing_scripts', 100 );

function apuslisting_listing_add_scripts() {
	wp_enqueue_style( 'leaflet', get_template_directory_uri() . '/assets/css/leaflet.css', array(), '0.7.7' );
	wp_enqueue_script( 'leaflet', get_template_directory_uri() . '/assets/js/leaflet.js', array( 'jquery' ), '0.7.7', true );
	wp_enqueue_script( 'apuslisting-job-listing', get_template_directory_uri() . '/assets/js/job.listing.js', array( 'jquery' ), '0.7.7', true );

	$mapbox_token = '';
	$mapbox_style = '';
	$custom_style = '';
	if ( apuslisting_get_config('listing_map_style_type', '') == 'mapbox' ) {
		$mapbox_token = apuslisting_get_config('listing_mapbox_token', '');
		$mapbox_style = apuslisting_get_config('listing_mapbox_style', '');
	} else {
		$custom_style = apuslisting_get_config('listing_map_custom_style', '');
	}
	wp_localize_script( 'apuslisting-job-listing', 'listing_params', array(
		'login_url' => rtrim( esc_url( wp_login_url() ) , '/'),
		'strings' => array(
			'wp-job-manager-file-upload' => esc_html__( 'Add Photo', 'apuslisting' ),
			'no_job_listings_found' => esc_html__( 'No results', 'apuslisting' ),
			'results-no' => esc_html__( 'Results', 'apuslisting'),
		),
		'mapbox_token' => $mapbox_token,
		'mapbox_style' => $mapbox_style,
		'custom_style' => $custom_style,
		'default_icon' => get_template_directory_uri() . '/assets/images/default-icon.png'
	) );
}

function apuslisting_get_listings_page_url( $default_link = null  ) {
	//if there is a page set in the Listings settings use that
	$listings_page_id = get_option( 'job_manager_jobs_page_id', false );
	if ( ! empty( $listings_page_id ) ) {
		return get_permalink( $listings_page_id );
	}

	if ( $default_link !== null ) {
		return $default_link;
	}
	return get_post_type_archive_link( 'job_listing' );
}

function apuslisting_display_categories_icon( $terms ) {
	if ( ! is_wp_error( $terms ) && ( is_array( $terms ) || is_object( $terms ) ) ) {
		foreach ($terms as $term) {
			$icon = Taxonomy_MetaData_CMB2::get('job_listing_category', $term->term_id, 'icon');
			if ( !empty($icon) ) {
			?>
				<a href="<?php echo esc_url( get_term_link($term->term_id, 'job_listing_category') ); ?>" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $term->name); ?>">
					<img src="<?php echo esc_url($icon); ?>" alt="">
				</a>
			<?php
			}
		}
	}
}

function apuslisting_display_categories( $terms ) {
	if ( ! is_wp_error( $terms ) && ( is_array( $terms ) || is_object( $terms ) ) ) {
		echo '<strong>'.esc_html__('In: ','apuslisting').'</strong>';
		$i = 0;
		foreach ($terms as $term) {
			?>
				<?php if($i != 0) echo ', ';?>
				<a href="<?php echo esc_url( get_term_link($term->term_id, 'job_listing_category') ); ?>" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $term->name); ?>">
					<?php echo esc_attr( $term->name); ?>
				</a>

			<?php
			$i++;
		}
	}
}

function apuslisting_display_hidden_category_icon( $terms ) {
	if ( ! is_wp_error( $terms ) && ( is_array( $terms ) || is_object( $terms ) ) ) {
		foreach ($terms as $term) {
			$icon = Taxonomy_MetaData_CMB2::get('job_listing_category', $term->term_id, 'icon');
			if ( !empty($icon) ) {
				?>
				<div class="listing-cat-icon hidden">
					<img src="<?php echo esc_url_raw($icon); ?>" alt="">
				</div>
				<?php
				return;
			}
		}
	}
}

function apuslisting_get_days_of_week() {
	$days = array(0, 1, 2, 3, 4, 5, 6);

	$start_day = get_option( 'start_of_week' );

	$first = array_splice( $days, $start_day, count( $days ) - $start_day );

	$second = array_splice( $days, 0, $start_day );

	$days = array_merge( $first, $second );

	return $days;
}

function apuslisting_get_day_hours($hours) {
	global $wp_locale;
	if (empty($hours) || !is_array($hours)) {
		return;
	}
    $numericdays = apuslisting_get_days_of_week();
    $days = array();
    foreach ( $numericdays as $key => $i ) {
        $day = $wp_locale->get_weekday( $i );
        $start = isset( $hours[ $i ][ 'start' ] ) ? $hours[ $i ][ 'start' ] : false;
        $end = isset( $hours[ $i ][ 'end' ] ) ? $hours[ $i ][ 'end' ] : false;

        if ( ! ( $start && $end ) ) {
            continue;
        }

        $days[ strtolower($day) ] = array( $start, $end );
    }
    return $days;
}

function apuslisting_set_course_views($content) {
	global $post;
	if ( $post->post_type != 'job_listing' ) {
		return $content;
	}
    $count_key = '_views_count';
    $count = get_post_meta($post->ID, $count_key, true);
    if ($count == '') {
        delete_post_meta($post->ID, $count_key);
        add_post_meta($post->ID, $count_key, 1);
    } else {
        $count++;
        $value = sanitize_text_field($count);
        update_post_meta($post->ID, $count_key, $value);
    }
    return $content;
}
//To keep the count accurate, lets get rid of prefetching
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
add_filter( 'the_content', 'apuslisting_set_course_views' );

function apuslisting_get_content_sort() {
	$contents = apuslisting_get_config( 'listing_single_sort_content', array() );

	if ( isset( $contents['enabled'] ) ) {
		$contents = $contents['enabled'];
		if ( isset($contents['placebo']) ) {
			unset($contents['placebo']);
		}
		return $contents;
	}

	return array();
}

function apuslisting_get_sidebar_content_sort() {
	$contents = apuslisting_get_config( 'listing_single_sort_sidebar', array() );

	if ( isset( $contents['enabled'] ) ) {
		$contents = $contents['enabled'];
		if ( isset($contents['placebo']) ) {
			unset($contents['placebo']);
		}
		return $contents;
	}

	return array();
}

function apuslisting_follow_user() {
	if ( !is_user_logged_in() ) {
		echo json_encode( array('status' => 'error', 'msg' => esc_html__('Please login to follow', 'apuslisting') ) );
		die();
	}
	$current_user_id = get_current_user_id();
	if ( $current_user_id == $user->ID ) {
		echo json_encode( array('status' => 'error', 'msg' => esc_html__('You can not follow yourself', 'apuslisting') ) );
		die();
	}
	$user_id = !empty($_POST['user_id']) ? $_POST['user_id'] : '';
	if ( empty($user_id) ) {
		echo json_encode( array('status' => 'error', 'msg' => esc_html__('Can not follow this user', 'apuslisting') ) );
		die();
	}
	$meta_key = '_apus_following';
	
	$data = get_user_meta( $current_user_id, $meta_key, true );

	if ( !empty($data) && is_array($data) && !empty($data[$user_id]) ) {
		unset($data[$user_id]);
		$class = 'btn-follow-user';
	} else {
		if ( is_array($data) ) {
			$data[$user_id] = $user_id;
		} else {
			$data = array($user_id => $user_id);
		}
		$class = 'btn-following-user';
	}
	update_user_meta( $current_user_id, $meta_key, $data );

	// follower
	$follower_meta_key = '_apus_followers';
	$data = get_user_meta( $user_id, $follower_meta_key, true );

	if ( !empty($data) && is_array($data) && !empty($data[$current_user_id]) ) {
		unset($data[$current_user_id]);
		$class = 'btn-follow-user';
		$msg = esc_html__('Follow', 'apuslisting');
	} else {
		if ( is_array($data) ) {
			$data[$current_user_id] = $current_user_id;
		} else {
			$data = array($current_user_id => $current_user_id);
		}
		$class = 'btn-following-user';
		$msg = '<span class="text-following">'.esc_html__('Following', 'apuslisting').'</span>
				<span class="text-following-hover">'.esc_html__('Unfollow', 'apuslisting').'</span>';
	}
	update_user_meta( $user_id, $follower_meta_key, $data );

	echo json_encode( array('status' => 'success', 'class' => $class, 'msg' => $msg) );
	die();
}
add_action( 'wp_ajax_apuslisting_follow_user', 'apuslisting_follow_user' );
add_action( 'wp_ajax_nopriv_apuslisting_follow_user', 'apuslisting_follow_user' );

function apuslisting_check_follow_user($user_id) {
	$current_user_id = get_current_user_id();
	$data = get_user_meta( $current_user_id, '_apus_following', true );
	if ( !empty($data) && is_array($data) && !empty($data[$user_id]) ) {
		return true;
	}
	return false;
}

function apuslisting_listing_display_part($template) {
	ob_start();
	get_template_part( 'job_manager/single/parts/'.$template );
	$content = ob_get_clean();
	echo trim( apply_filters( 'apuslisting_listing_display_part', $content, $template ) );
}

function apuslisting_listing_favorite_btn($post_id) {
	if ( class_exists('ApusApusListing_Template_Loader') ) {
		echo ApusApusListing_Template_Loader::get_template_part( 'favorite/button-detail', array( 'post_id' => $post_id ) );
	}
}

function apuslisting_job_manager_chosen_enabled($return) {
    return true;
}
add_filter( 'job_manager_enhanced_select_enabled', 'apuslisting_job_manager_chosen_enabled', 100 );

function apuslisting_child_add_tax_to_api() {
	$tax = get_taxonomy( 'job_listing_region' );
	if ( $tax ) {
		$tax->show_in_rest = true;
	}
	$tax = get_taxonomy( 'job_listing_amenity' );
	if ( $tax ) {
		$tax->show_in_rest = true;
	}
}
add_action( 'init', 'apuslisting_child_add_tax_to_api', 30 );